@@ -1,10 +1,11 @@
 # Desired capabilities example file for BrowserStack
 # Generate from https://www.browserstack.com/automate/capabilities
 desired_cap = {
-    "os": "OS X",
-    "os_version": "High Sierra",
+    "os": "Windows",
+    "os_version": "11",
     "browser": "Chrome",
-    "browser_version": "77.0",
+    "browser_version": "101.0",
     "browserstack.local": "false",
-    "browserstack.selenium_version": "3.141.59",
+    "browserstack.debug": "true",
+    "browserstack.selenium_version": "4.1.2",
 }
