@@ -5,7 +5,7 @@ change the values here and add "--settings=custom_settings.py" when running.
 
 # Default timeout values for waiting for page elements to appear.
 MINI_TIMEOUT = 2
-SMALL_TIMEOUT = 6
+SMALL_TIMEOUT = 7
 LARGE_TIMEOUT = 10
 EXTREME_TIMEOUT = 30
 
@@ -13,9 +13,13 @@ EXTREME_TIMEOUT = 30
 ARCHIVE_EXISTING_LOGS = False
 ARCHIVE_EXISTING_DOWNLOADS = False
 
+# If True, switch to new tabs automatically if a click opens a new one.
+# (Only happens if the initial tab is still on same URL as before.)
+SWITCH_TO_NEW_TABS_ON_CLICK = True
+
 # Waiting for Document.readyState to be "Complete" after browser actions.
 WAIT_FOR_RSC_ON_PAGE_LOADS = True
-WAIT_FOR_RSC_ON_CLICKS = True
+WAIT_FOR_RSC_ON_CLICKS = False
 WAIT_FOR_ANGULARJS = True
 
 # Changing the default behavior of Demo Mode. Activate with: --demo_mode
