@@ -1,6 +1,6 @@
 """
 This test is only for Microsoft Edge (Chromium)!
-(Tested on Edge Version 89.0.774.54)
+(Tested on Edge Version 96.0.1054.62)
 """
 from seleniumbase import BaseCase
 
@@ -8,10 +8,12 @@ from seleniumbase import BaseCase
 class EdgeTests(BaseCase):
     def test_edge(self):
         if self.browser != "edge":
+            self.open("data:,")
             print("\n  This test is only for Microsoft Edge (Chromium)!")
             print('  (Run this test using "--edge" or "--browser=edge")')
             self.skip('Use "--edge" or "--browser=edge"')
         if self.headless:
+            self.open_if_not_url("about:blank")
             print("\n  This test is NOT designed for Headless Mode!")
             self.skip('Do NOT use "--headless" with this test!')
         self.open("edge://settings/help")
