@@ -3,8 +3,6 @@ from seleniumbase import BaseCase
 
 class HandleAlertTests(BaseCase):
     def test_alerts(self):
-        if self.browser == "safari":
-            self.skip("This test doesn't run on Safari! (alert issues)")
         self.open("about:blank")
         self.execute_script('window.alert("ALERT!!!");')
         self.sleep(1)  # Not needed (Lets you see the alert pop up)
