@@ -1,14 +1,13 @@
-import time
 from seleniumbase import BaseCase
 
 
 class ProxyTests(BaseCase):
     def test_proxy(self):
         self.open("https://ipinfo.io/")
-        ip_address = self.get_text("div.home-ip-details span.value")[1:-1]
+        ip_address = self.get_text('#ip-string span[class*="primary"] span')
         print("\n\nMy IP Address = %s\n" % ip_address)
         print("Displaying Host Info:")
-        text = self.get_text("div.home-ip-details").split("asn:")[0]
+        text = self.get_text("#widget-scrollable-container").split("asn:")[0]
         rows = text.split("\n")
         data = []
         for row in rows:
@@ -16,4 +15,4 @@ class ProxyTests(BaseCase):
                 data.append(row.strip())
         print("\n".join(data).replace('\n"', " "))
         print("\nThe browser will close automatically in 7 seconds...")
-        time.sleep(7)
+        self.sleep(7)
