@@ -3,17 +3,18 @@ This test demonstrates the use of the "rate_limited" decorator.
 You can use this decorator on any method to rate-limit it.
 """
 
-import unittest
+from seleniumbase import BaseCase
 from seleniumbase import decorators
 
 
-class MyTestClass(unittest.TestCase):
-
-    @decorators.rate_limited(3.5)  # The arg is max calls per second
+class RateLimitingTests(BaseCase):
+    @decorators.rate_limited(4.2)  # The arg is max calls per second
     def print_item(self, item):
         print(item)
 
     def test_rate_limited_printing(self):
-        print("\nRunning rate-limited print test:")
+        message = "Running rate-limited print() on the command line"
+        self.open("data:text/html,<p>%s</p>" % message)
+        print("\n%s:" % message)
         for item in range(1, 11):
             self.print_item(item)
