@@ -29,16 +29,23 @@ except (ImportError, ValueError):
     pure_python = True
 
 if pure_python:
-    sb = MyTestClass("test_basics")
+    sb = MyTestClass("test_swag_labs")
     sb.browser = "chrome"
+    sb.is_behave = False
     sb.headless = False
     sb.headed = False
+    sb.xvfb = False
     sb.start_page = None
     sb.locale_code = None
     sb.protocol = "http"
     sb.servername = "localhost"
     sb.port = 4444
     sb.data = None
+    sb.var1 = None
+    sb.var2 = None
+    sb.var3 = None
+    sb.variables = {}
+    sb.account = None
     sb.environment = "test"
     sb.user_agent = None
     sb.incognito = False
@@ -61,7 +68,9 @@ if pure_python:
     sb._multithreaded = False
     sb._reuse_session = False
     sb._crumbs = False
+    sb._final_debug = False
     sb.visual_baseline = False
+    sb.window_size = None
     sb.maximize_option = False
     sb.save_screenshot_after_test = False
     sb.timeout_multiplier = None
@@ -69,16 +78,23 @@ if pure_python:
     sb.with_db_reporting = False
     sb.with_s3_logging = False
     sb.js_checking_on = False
+    sb.recorder_mode = False
+    sb.recorder_ext = False
+    sb.record_sleep = False
+    sb.rec_behave = False
+    sb.rec_print = False
     sb.report_on = False
     sb.is_pytest = False
     sb.slow_mode = False
     sb.demo_mode = False
     sb.time_limit = None
-    sb.demo_sleep = 1
+    sb.demo_sleep = None
     sb.dashboard = False
     sb._dash_initialized = False
-    sb.message_duration = 2
+    sb.message_duration = None
     sb.block_images = False
+    sb.do_not_track = False
+    sb.external_pdf = False
     sb.remote_debug = False
     sb.settings_file = None
     sb.user_data_dir = None
@@ -86,17 +102,18 @@ if pure_python:
     sb.firefox_arg = None
     sb.firefox_pref = None
     sb.proxy_string = None
+    sb.proxy_bypass_list = None
+    sb.proxy_pac_url = None
     sb.swiftshader = False
     sb.ad_block_on = False
     sb.highlights = None
-    sb.check_js = False
     sb.interval = None
     sb.cap_file = None
     sb.cap_string = None
 
     sb.setUp()
     try:
-        sb.test_basics()
+        sb.test_swag_labs()
     finally:
         sb.tearDown()
         del sb
