@@ -4,7 +4,7 @@ from seleniumbase import BaseCase
 
 class SwagLabsTests(BaseCase):
     def login_to_swag_labs(self, username="standard_user"):
-        """ Login to Swag Labs and verify success. """
+        """Login to Swag Labs and verify success."""
         url = "https://www.saucedemo.com"
         self.open(url)
         if username not in self.get_text("#login_credentials"):
@@ -12,7 +12,7 @@ class SwagLabsTests(BaseCase):
         self.type("#user-name", username)
         self.type("#password", "secret_sauce")
         self.click('input[type="submit"]')
-        self.assert_element("#inventory_container")
+        self.assert_element("div.inventory_list")
         self.assert_element('div:contains("Sauce Labs Backpack")')
 
     @parameterized.expand(
@@ -45,7 +45,7 @@ class SwagLabsTests(BaseCase):
         self.assert_exact_text("1", "span.shopping_cart_badge")
 
         # Verify your cart
-        self.click("#shopping_cart_container")
+        self.click("#shopping_cart_container a")
         self.assert_element('span:contains("Your Cart")')
         self.assert_text(item_name, "div.inventory_item_name")
         self.assert_exact_text("1", "div.cart_quantity")
@@ -72,7 +72,7 @@ class SwagLabsTests(BaseCase):
         self.click("button#finish")
         self.assert_exact_text("THANK YOU FOR YOUR ORDER", "h2")
         self.assert_element("img.pony_express")
-        self.click("#shopping_cart_container")
+        self.click("#shopping_cart_container a")
         self.assert_element_absent("div.inventory_item_name")
         self.click("button#continue-shopping")
         self.assert_element_absent("span.shopping_cart_badge")
