@@ -31,6 +31,9 @@ class EventFiringTests(BaseCase):
         print("\n* EventFiringWebDriver example *")
         self.open("https://xkcd.com/1862/")
         self.click("link=About")
-        self.open("https://store.xkcd.com/search")
-        self.type('input[name="q"]', "xkcd book\n")
-        self.open("https://xkcd.com/1822/")
+        self.open("https://xkcd.com/1820/")
+        self.assert_text("Security Advice", "#ctitle")
+        self.click('a:contains("Next >")')
+        self.assert_text("Incinerator", "#ctitle")
+        self.click('a[rel="next"]')
+        self.assert_text("Existential Bug Reports", "#ctitle")
