@@ -8,10 +8,9 @@ import pytest
 from seleniumbase import BaseCase
 
 
-class MyTestClass(BaseCase):
-
+class FailingTests(BaseCase):
     @pytest.mark.expected_failure
     def test_find_army_of_robots_on_xkcd_desert_island(self):
         self.open("https://xkcd.com/731/")
-        print("\n(This test fails on purpose)")
+        print("\n(This test should fail)")
         self.assert_element("div#ARMY_OF_ROBOTS", timeout=1)
