@@ -1,11 +1,10 @@
-''' This test suite contains 2 passing tests and 2 failing tests. '''
+""" This test suite contains 2 passing tests and 2 failing tests. """
 
 import pytest
 from seleniumbase import BaseCase
 
 
 class MyTestSuite(BaseCase):
-
     def test_1(self):
         self.open("https://xkcd.com/1664/")
         self.assert_text("Mycology", "div#ctitle", timeout=4)
@@ -15,7 +14,7 @@ class MyTestSuite(BaseCase):
 
     @pytest.mark.expected_failure
     def test_2(self):
-        print("\n(This test fails on purpose)")
+        print("\n(This test should fail)")
         self.open("https://xkcd.com/1675/")
         raise Exception("FAKE EXCEPTION: This test fails on purpose.")
 
@@ -27,6 +26,6 @@ class MyTestSuite(BaseCase):
 
     @pytest.mark.expected_failure
     def test_4(self):
-        print("\n(This test fails on purpose)")
+        print("\n(This test should fail)")
         self.open("https://xkcd.com/1670/")
         self.assert_element("FakeElement.DoesNotExist", timeout=0.5)
