@@ -5,6 +5,7 @@ class MyTourClass(BaseCase):
     def test_google_tour(self):
         self.open("https://google.com/ncr")
         self.wait_for_element('input[title="Search"]')
+        self.hide_elements("iframe")
 
         # Create a website tour using the ShepherdJS library with "dark" theme
         # Same as:  self.create_shepherd_tour(theme="dark")
@@ -13,7 +14,7 @@ class MyTourClass(BaseCase):
         self.add_tour_step("Type in your query here.", 'input[title="Search"]')
         self.play_tour()
 
-        self.highlight_update_text('input[title="Search"]', "Google")
+        self.highlight_type('input[title="Search"]', "Google")
         self.wait_for_element('[role="listbox"]')  # Wait for autocomplete
 
         # Create a website tour using the ShepherdJS library with "light" theme
@@ -23,7 +24,7 @@ class MyTourClass(BaseCase):
         self.add_tour_step("Or press [ENTER] after entry.", '[title="Search"]')
         self.play_tour()
 
-        self.highlight_update_text('input[title="Search"]', "GitHub\n")
+        self.highlight_type('input[title="Search"]', "GitHub\n")
         self.ad_block()
         self.wait_for_element("#search")
 
@@ -42,9 +43,9 @@ class MyTourClass(BaseCase):
         # Create a website tour using the IntroJS library
         # Same as:  self.create_introjs_tour()
         self.create_tour(theme="introjs")
-        self.add_tour_step("Welcome to Google Maps!")
+        self.add_tour_step("Welcome to Google Maps", title="SeleniumBase Tour")
         self.add_tour_step(
-            "Type in a location here.", "#searchboxinput", title="Search Box"
+            "The location goes here.", "#searchboxinput", title="Search Box"
         )
         self.add_tour_step(
             "Then click here to show it on the map.",
@@ -53,12 +54,12 @@ class MyTourClass(BaseCase):
         )
         self.add_tour_step(
             "Or click here to get driving directions.",
-            "#searchbox-directions",
+            'button[aria-label="Directions"]',
             alignment="bottom",
         )
         self.add_tour_step(
             "Use this button to switch to Satellite view.",
-            "#minimap div.widget-minimap",
+            'button[jsaction*="minimap.main;"]',
             alignment="right",
         )
         self.add_tour_step(
@@ -69,7 +70,7 @@ class MyTourClass(BaseCase):
         )
         self.add_tour_step(
             "Use the Menu button to see more options.",
-            ".searchbox-hamburger-container",
+            'button[jsaction*="settings.open;"]',
             alignment="right",
         )
         self.add_tour_step(
