@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from seleniumbase import BaseCase
 
 
@@ -10,10 +11,10 @@ class MyTourClass(BaseCase):
 
         self.create_tour(theme="introjs")
         self.add_tour_step(
-            "Welcome to Google Maps!", title="✅ SeleniumBase Tours 🌎"
+            "Welcome to Google Maps", title="✅ SeleniumBase Tours 🌎"
         )
         self.add_tour_step(
-            "Type in a location here.", "#searchboxinput", title="Search Box"
+            "The location goes here.", "#searchboxinput", title="Search Box"
         )
         self.add_tour_step(
             "Then click here to show it on the map.",
@@ -22,12 +23,12 @@ class MyTourClass(BaseCase):
         )
         self.add_tour_step(
             "Or click here to get driving directions.",
-            "#searchbox-directions",
+            'button[aria-label="Directions"]',
             alignment="bottom",
         )
         self.add_tour_step(
             "Use this button to switch to Satellite view.",
-            "#minimap div.widget-minimap",
+            'button[jsaction*="minimap.main;"]',
             alignment="right",
         )
         self.add_tour_step(
@@ -38,7 +39,7 @@ class MyTourClass(BaseCase):
         )
         self.add_tour_step(
             "Use the Menu button to see more options.",
-            ".searchbox-hamburger-container",
+            'button[jsaction*="settings.open;"]',
             alignment="right",
         )
         self.add_tour_step(
@@ -50,5 +51,5 @@ class MyTourClass(BaseCase):
             "Thanks for using SeleniumBase Tours!",
             title="🚃 End of Guided Tour 🚃",
         )
-        self.export_tour(filename="google_maps_introjs_tour.js")
+        self.export_tour(filename="maps_introjs_tour.js")
         self.play_tour()
