@@ -16,7 +16,7 @@ class MyTourClass(BaseCase):
         self.add_tour_step(
             "This is not the page you're looking for.", 'img[alt*="404"]'
         )
-        self.add_tour_step("<b>Have a great day!</b>", title="☀️ ☀️ ☀️ ☀️")
+        self.add_tour_step("<b>Have a great day!</b>", title="😃 ☀️ 😁")
         self.add_tour_step("<b>And may the Force be with you!</b>", title="⭐")
         self.export_tour(filename="octocat_tour.js")
         self.play_tour()
