@@ -2,9 +2,8 @@ from seleniumbase import BaseCase
 
 
 class MyTestClass(BaseCase):
-
     def test_create_tour(self):
-        self.open('https://xkcd.com/1117/')
+        self.open("https://xkcd.com/1117/")
         self.assert_element('img[alt="My Sky"]')
         self.create_tour(theme="dark")
         self.add_tour_step("Welcome to XKCD!")
