@@ -12,10 +12,10 @@ class 我的测试类(硒测试用例):
         self.单击("#searchButton")
         self.断言文本("舞龍", "#firstHeading")
         self.断言元素('img[src*="Chinese_draak.jpg"]')
-        self.输入文本("#searchInput", "火鍋")
+        self.输入文本("#searchInput", "麻婆豆腐")
         self.单击("#searchButton")
-        self.断言文本("火鍋", "#firstHeading")
-        self.断言元素('td:contains("火鍋的各種食材")')
+        self.断言文本("麻婆豆腐", "#firstHeading")
+        self.断言元素('div.thumb div:contains("一家中餐館的麻婆豆腐")')
         self.输入文本("#searchInput", "精武英雄")
         self.单击("#searchButton")
         self.断言元素('img[src*="Fist_of_legend.jpg"]')
