@@ -3,7 +3,6 @@ from seleniumbase.translate.russian import ТестНаСелен  # noqa
 
 
 class МойТестовыйКласс(ТестНаСелен):
-
     def test_пример_1(self):
         self.открыть("https://ru.wikipedia.org/wiki/")
         self.подтвердить_элемент('[title="Русский язык"]')
@@ -11,7 +10,7 @@ class МойТестовыйКласс(ТестНаСелен):
         self.введите("#searchInput", "МГУ")
         self.нажмите("#searchButton")
         self.подтвердить_текст("университет", "#firstHeading")
-        self.подтвердить_элемент('img[alt="МГУ, вид с воздуха.jpg"]')
+        self.подтвердить_элемент('img[alt*="Главное здание МГУ"]')
         self.введите("#searchInput", "приключения Шурика")
         self.нажмите("#searchButton")
         self.подтвердить_текст("Операция «Ы» и другие приключения Шурика")
