@@ -6,11 +6,19 @@ seleniumbase [COMMAND] [PARAMETERS]
   OR   sbase [COMMAND] [PARAMETERS]
 
 Examples:
-sbase install chromedriver
+sbase get chromedriver
 sbase methods
 sbase options
+sbase commander
+sbase behave-gui
 sbase mkdir ui_tests
 sbase mkfile new_test.py
+sbase mkrec new_test.py
+sbase mkrec new_test.py --url=wikipedia.org
+sbase codegen new_test.py --url=wikipedia.org
+sbase recorder
+sbase record new_test.py
+sbase record
 sbase mkpres new_presentation.py
 sbase mkchart new_chart.py
 sbase convert webdriver_unittest_file.py
@@ -38,7 +46,7 @@ def show_usage():
     sc = ""
     sc += '    Type "sbase help [COMMAND]" for specific command info.\n'
     sc += '    For info on all commands, type: "seleniumbase --help".\n'
-    sc += ' * (Use "pytest" for running tests) *\n'
+    sc += '    Use "pytest" for running tests.\n'
     if "linux" not in sys.platform:
         c1 = colorama.Fore.BLUE + colorama.Back.LIGHTCYAN_EX
         c2 = colorama.Fore.BLUE + colorama.Back.LIGHTGREEN_EX
@@ -69,26 +77,32 @@ def show_basic_usage():
     sc += ' *    OR:        "sbase [COMMAND] [PARAMETERS]"\n'
     sc += "\n"
     sc += "COMMANDS:\n"
-    sc += "      install         [DRIVER] [OPTIONS]\n"
-    sc += "      methods         (List common Python methods)\n"
-    sc += "      options         (List common pytest options)\n"
-    sc += "      mkdir           [DIRECTORY] [OPTIONS]\n"
-    sc += "      mkfile          [FILE.py] [OPTIONS]\n"
-    sc += "      mkpres          [FILE.py] [LANG]\n"
-    sc += "      mkchart         [FILE.py] [LANG]\n"
-    sc += "      print           [FILE] [OPTIONS]\n"
-    sc += "      translate       [SB_FILE.py] [LANG] [ACTION]\n"
-    sc += "      convert         [WEBDRIVER_UNITTEST_FILE.py]\n"
-    sc += "      extract-objects [SB_FILE.py]\n"
-    sc += "      inject-objects  [SB_FILE.py] [OPTIONS]\n"
-    sc += "      objectify       [SB_FILE.py] [OPTIONS]\n"
-    sc += "      revert-objects  [SB_FILE.py] [OPTIONS]\n"
-    sc += "      encrypt         (OR: obfuscate)\n"
-    sc += "      decrypt         (OR: unobfuscate)\n"
-    sc += "      download server (The Selenium Grid JAR file)\n"
-    sc += "      grid-hub        [start|stop] [OPTIONS]\n"
-    sc += "      grid-node       [start|stop] --hub=[HOST/IP]\n"
-    sc += ' * (EXAMPLE: "sbase install chromedriver latest")  *\n'
+    sc += "      get / install    [DRIVER] [OPTIONS]\n"
+    sc += "      methods          (List common Python methods)\n"
+    sc += "      options          (List common pytest options)\n"
+    sc += "      behave-options   (List common behave options)\n"
+    sc += "      gui / commander  [OPTIONAL PATH or TEST FILE]\n"
+    sc += "      behave-gui       (SBase Commander for Behave)\n"
+    sc += "      mkdir            [DIRECTORY] [OPTIONS]\n"
+    sc += "      mkfile           [FILE.py] [OPTIONS]\n"
+    sc += "      mkrec / codegen  [FILE.py] [OPTIONS]\n"
+    sc += "      recorder         (Open Recorder Desktop App.)\n"
+    sc += "      record           (If args: mkrec. Else: App.)\n"
+    sc += "      mkpres           [FILE.py] [LANG]\n"
+    sc += "      mkchart          [FILE.py] [LANG]\n"
+    sc += "      print            [FILE] [OPTIONS]\n"
+    sc += "      translate        [SB_FILE.py] [LANG] [ACTION]\n"
+    sc += "      convert          [WEBDRIVER_UNITTEST_FILE.py]\n"
+    sc += "      extract-objects  [SB_FILE.py]\n"
+    sc += "      inject-objects   [SB_FILE.py] [OPTIONS]\n"
+    sc += "      objectify        [SB_FILE.py] [OPTIONS]\n"
+    sc += "      revert-objects   [SB_FILE.py] [OPTIONS]\n"
+    sc += "      encrypt / obfuscate\n"
+    sc += "      decrypt / unobfuscate\n"
+    sc += "      download server  (Get Selenium Grid JAR file)\n"
+    sc += "      grid-hub         [start|stop] [OPTIONS]\n"
+    sc += "      grid-node        [start|stop] --hub=[HOST/IP]\n"
+    sc += ' * (EXAMPLE: "sbase get chromedriver latest") *\n'
     sc += ""
     if "linux" not in sys.platform:
         c1 = colorama.Fore.BLUE + colorama.Back.LIGHTCYAN_EX
@@ -103,31 +117,37 @@ def show_install_usage():
     c2 = colorama.Fore.BLUE + colorama.Back.LIGHTGREEN_EX
     c3 = colorama.Fore.BLUE + colorama.Back.LIGHTYELLOW_EX
     cr = colorama.Style.RESET_ALL
-    sc = "  " + c2 + "** " + c3 + "install" + c2 + " **" + cr
+    sc = "  " + c2 + "** " + c3 + "get / install" + c2 + " **" + cr
     print(sc)
     print("")
     print("  Usage:")
     print("           seleniumbase install [DRIVER_NAME] [OPTIONS]")
+    print("           OR: seleniumbase get [DRIVER_NAME] [OPTIONS]")
     print("           OR:    sbase install [DRIVER_NAME] [OPTIONS]")
+    print("           OR:        sbase get [DRIVER_NAME] [OPTIONS]")
     print("                 (Drivers: chromedriver, geckodriver, edgedriver")
     print("                           iedriver, operadriver)")
     print("  Options:")
-    print("           VERSION         Specify the version.")
-    print("                           (Default Chromedriver version = 2.44)")
-    print('                           Use "latest" for the latest version.')
+    print("           VERSION         Specify the version to download.")
+    print("                            (Default chromedriver = 72.0.3626.69.")
+    print('                             Use "latest" for the latest version.')
+    print("                             For chromedriver, you can also use")
+    print("                             the major version integer")
+    print('                             or "latest-1" for 1 less than that.)')
     print("           -p OR --path    Also copy the driver to /usr/local/bin")
-    print("  Example:")
-    print("           sbase install chromedriver")
-    print("           sbase install geckodriver")
-    print("           sbase install edgedriver")
-    print("           sbase install chromedriver 91")
-    print("           sbase install chromedriver 91.0.4472.101")
-    print("           sbase install chromedriver latest")
-    print("           sbase install chromedriver -p")
-    print("           sbase install chromedriver latest -p")
-    print("           sbase install edgedriver 91.0.864.67")
+    print("  Examples:")
+    print("           sbase get chromedriver")
+    print("           sbase get geckodriver")
+    print("           sbase get edgedriver")
+    print("           sbase get chromedriver 102")
+    print("           sbase get chromedriver 102.0.5005.61")
+    print("           sbase get chromedriver latest")
+    print("           sbase get chromedriver latest-1")
+    print("           sbase get chromedriver -p")
+    print("           sbase get chromedriver latest -p")
+    print("           sbase get edgedriver 102.0.1245.44")
     print("  Output:")
-    print("           Installs the chosen webdriver to seleniumbase/drivers/")
+    print("           Downloads the chosen webdriver to seleniumbase/drivers")
     print("           (chromedriver is required for Chrome automation)")
     print("           (geckodriver is required for Firefox automation)")
     print("           (edgedriver is required for Microsoft Edge automation)")
@@ -136,6 +156,50 @@ def show_install_usage():
     print("")
 
 
+def show_commander_usage():
+    c2 = colorama.Fore.BLUE + colorama.Back.LIGHTGREEN_EX
+    c3 = colorama.Fore.BLUE + colorama.Back.LIGHTYELLOW_EX
+    cr = colorama.Style.RESET_ALL
+    sc = "  " + c2 + "** " + c3 + "commander" + c2 + " **" + cr
+    print(sc)
+    print("")
+    print("  Usage:")
+    print("           seleniumbase commander [OPTIONAL PATH or TEST FILE]")
+    print("           OR:    sbase commander [OPTIONAL PATH or TEST FILE]")
+    print("           OR:   seleniumbase gui [OPTIONAL PATH or TEST FILE]")
+    print("           OR:          sbase gui [OPTIONAL PATH or TEST FILE]")
+    print("  Examples:")
+    print("           sbase gui")
+    print("           sbase gui -k agent")
+    print("           sbase gui -m marker2")
+    print("           sbase gui test_suite.py")
+    print("           sbase gui offline_examples/")
+    print("  Output:")
+    print("           Launches SeleniumBase Commander | GUI for pytest.")
+    print("")
+
+
+def show_behave_gui_usage():
+    c2 = colorama.Fore.BLUE + colorama.Back.LIGHTGREEN_EX
+    c3 = colorama.Fore.BLUE + colorama.Back.LIGHTYELLOW_EX
+    cr = colorama.Style.RESET_ALL
+    sc = "  " + c2 + "** " + c3 + "behave-gui" + c2 + " **" + cr
+    print(sc)
+    print("")
+    print("  Usage:")
+    print("           seleniumbase behave-gui [OPTIONAL PATH or TEST FILE]")
+    print("           seleniumbase gui-behave [OPTIONAL PATH or TEST FILE]")
+    print("           OR:    sbase behave-gui [OPTIONAL PATH or TEST FILE]")
+    print("           OR:    sbase gui-behave [OPTIONAL PATH or TEST FILE]")
+    print("  Examples:")
+    print("           sbase behave-gui")
+    print("           sbase behave-gui features/")
+    print("           sbase behave-gui features/calculator.feature")
+    print("  Output:")
+    print("           Launches SeleniumBase Commander | GUI for Behave.")
+    print("")
+
+
 def show_mkdir_usage():
     c2 = colorama.Fore.BLUE + colorama.Back.LIGHTGREEN_EX
     c3 = colorama.Fore.BLUE + colorama.Back.LIGHTYELLOW_EX
@@ -149,7 +213,7 @@ def show_mkdir_usage():
     print("  Example:")
     print("           sbase mkdir ui_tests")
     print("  Options:")
-    print("         -b / --basic  (Only config files. No tests added.)")
+    print("           -b / --basic  (Only config files. No tests added.)")
     print("  Output:")
     print("           Creates a new folder for running SBase scripts.")
     print("           The new folder contains default config files,")
@@ -172,22 +236,90 @@ def show_mkfile_usage():
     print("  Example:")
     print("           sbase mkfile new_test.py")
     print("  Options:")
-    print("          -b / --basic  (Basic boilerplate / single-line test)")
+    print("           -b / --basic  (Basic boilerplate / single-line test)")
+    print("           -r / --rec  (adds ipdb breakpoint for Recorder Mode)")
     print("  Language Options:")
-    print("          --en / --English    |    --zh / --Chinese")
-    print("          --nl / --Dutch      |    --fr / --French")
-    print("          --it / --Italian    |    --ja / --Japanese")
-    print("          --ko / --Korean     |    --pt / --Portuguese")
-    print("          --ru / --Russian    |    --es / --Spanish")
+    print("           --en / --English    |    --zh / --Chinese")
+    print("           --nl / --Dutch      |    --fr / --French")
+    print("           --it / --Italian    |    --ja / --Japanese")
+    print("           --ko / --Korean     |    --pt / --Portuguese")
+    print("           --ru / --Russian    |    --es / --Spanish")
     print("  Output:")
-    print("          Creates a new SBase test file with boilerplate code.")
-    print("          If the file already exists, an error is raised.")
-    print("          By default, uses English mode and creates a")
-    print("          boilerplate with the 5 most common SeleniumBase")
-    print('          methods, which are "open", "type", "click",')
-    print('          "assert_element", and "assert_text". If using the')
-    print('          basic boilerplate option, only the "open" method')
-    print("          is included.")
+    print("           Creates a new SBase test file with boilerplate code.")
+    print("           If the file already exists, an error is raised.")
+    print("           By default, uses English mode and creates a")
+    print("           boilerplate with the 5 most common SeleniumBase")
+    print('           methods, which are "open", "type", "click",')
+    print('           "assert_element", and "assert_text". If using the')
+    print('           basic boilerplate option, only the "open" method')
+    print("           is included.")
+    print("")
+
+
+def show_mkrec_usage():
+    c2 = colorama.Fore.BLUE + colorama.Back.LIGHTGREEN_EX
+    c3 = colorama.Fore.BLUE + colorama.Back.LIGHTYELLOW_EX
+    cr = colorama.Style.RESET_ALL
+    sc = "  " + c2 + "** " + c3 + "mkrec" + c2 + " **" + cr
+    print(sc)
+    print("")
+    print("  Usage:")
+    print("           seleniumbase mkrec [FILE.py] [OPTIONS]")
+    print("           OR:    sbase mkrec [FILE.py] [OPTIONS]")
+    print("  Examples:")
+    print("           sbase mkrec new_test.py")
+    print("           sbase mkrec new_test.py --url=wikipedia.org")
+    print("  Options:")
+    print("           --url=URL  (Sets the initial start page URL.)")
+    print("           --edge  (Use Edge browser instead of Chrome.)")
+    print("           --gui / --headed  (Use headed mode on Linux.)")
+    print("           --overwrite  (Overwrite file when it exists.)")
+    print("           --behave  (Also output Behave/Gherkin files.)")
+    print("  Output:")
+    print("           Creates a new SeleniumBase test using the Recorder.")
+    print("           If the filename already exists, an error is raised.")
+    print("")
+
+
+def show_codegen_usage():
+    c2 = colorama.Fore.BLUE + colorama.Back.LIGHTGREEN_EX
+    c3 = colorama.Fore.BLUE + colorama.Back.LIGHTYELLOW_EX
+    cr = colorama.Style.RESET_ALL
+    sc = "  " + c2 + "** " + c3 + "codegen" + c2 + " **" + cr
+    print(sc)
+    print("")
+    print("  Usage:")
+    print("           seleniumbase codegen [FILE.py] [OPTIONS]")
+    print("           OR:    sbase codegen [FILE.py] [OPTIONS]")
+    print("  Examples:")
+    print("           sbase codegen new_test.py")
+    print("           sbase codegen new_test.py --url=wikipedia.org")
+    print("  Options:")
+    print("           --url=URL  (Sets the initial start page URL.)")
+    print("           --edge  (Use Edge browser instead of Chrome.)")
+    print("           --gui / --headed  (Use headed mode on Linux.)")
+    print("           --overwrite  (Overwrite file when it exists.)")
+    print("           --behave  (Also output Behave/Gherkin files.)")
+    print("  Output:")
+    print("           Creates a new SeleniumBase test using the Recorder.")
+    print("           If the filename already exists, an error is raised.")
+    print("")
+
+
+def show_recorder_usage():
+    c2 = colorama.Fore.BLUE + colorama.Back.LIGHTGREEN_EX
+    c3 = colorama.Fore.BLUE + colorama.Back.LIGHTYELLOW_EX
+    cr = colorama.Style.RESET_ALL
+    sc = "  " + c2 + "** " + c3 + "recorder" + c2 + " **" + cr
+    print(sc)
+    print("")
+    print("  Usage:")
+    print("           seleniumbase recorder [OPTIONS]")
+    print("           OR:    sbase recorder [OPTIONS]")
+    print("  Options:")
+    print("           --behave  (Also output Behave/Gherkin files.)")
+    print("  Output:")
+    print("           Launches the SeleniumBase Recorder Desktop App.")
     print("")
 
 
@@ -204,17 +336,17 @@ def show_mkpres_usage():
     print("  Example:")
     print("           sbase mkpres new_presentation.py --en")
     print("  Language Options:")
-    print("          --en / --English    |    --zh / --Chinese")
-    print("          --nl / --Dutch      |    --fr / --French")
-    print("          --it / --Italian    |    --ja / --Japanese")
-    print("          --ko / --Korean     |    --pt / --Portuguese")
-    print("          --ru / --Russian    |    --es / --Spanish")
+    print("           --en / --English    |    --zh / --Chinese")
+    print("           --nl / --Dutch      |    --fr / --French")
+    print("           --it / --Italian    |    --ja / --Japanese")
+    print("           --ko / --Korean     |    --pt / --Portuguese")
+    print("           --ru / --Russian    |    --es / --Spanish")
     print("  Output:")
-    print("          Creates a new presentation with 3 example slides.")
-    print("          If the file already exists, an error is raised.")
-    print("          By default, the slides are written in English,")
-    print('          and use "serif" theme with "slide" transition.')
-    print("          The slides can be used as a basic boilerplate.")
+    print("           Creates a new presentation with 3 example slides.")
+    print("           If the file already exists, an error is raised.")
+    print("           By default, the slides are written in English,")
+    print('           and use "serif" theme with "slide" transition.')
+    print("           The slides can be used as a basic boilerplate.")
     print("")
 
 
@@ -231,17 +363,17 @@ def show_mkchart_usage():
     print("  Example:")
     print("           sbase mkchart new_chart.py --en")
     print("  Language Options:")
-    print("          --en / --English    |    --zh / --Chinese")
-    print("          --nl / --Dutch      |    --fr / --French")
-    print("          --it / --Italian    |    --ja / --Japanese")
-    print("          --ko / --Korean     |    --pt / --Portuguese")
-    print("          --ru / --Russian    |    --es / --Spanish")
+    print("           --en / --English    |    --zh / --Chinese")
+    print("           --nl / --Dutch      |    --fr / --French")
+    print("           --it / --Italian    |    --ja / --Japanese")
+    print("           --ko / --Korean     |    --pt / --Portuguese")
+    print("           --ru / --Russian    |    --es / --Spanish")
     print("  Output:")
-    print("          Creates a new SeleniumBase chart presentation.")
-    print("          If the file already exists, an error is raised.")
-    print("          By default, the slides are written in English,")
-    print('          and use a "sky" theme with "slide" transition.')
-    print("          The chart can be used as a basic boilerplate.")
+    print("           Creates a new SeleniumBase chart presentation.")
+    print("           If the file already exists, an error is raised.")
+    print("           By default, the slides are written in English,")
+    print('           and use a "sky" theme with "slide" transition.')
+    print("           The chart can be used as a basic boilerplate.")
     print("")
 
 
@@ -272,13 +404,13 @@ def show_print_usage():
     print(sc)
     print("")
     print("  Usage:")
-    print("         seleniumbase print [FILE] [OPTIONS]")
-    print("         OR:    sbase print [FILE] [OPTIONS]")
+    print("           seleniumbase print [FILE] [OPTIONS]")
+    print("           OR:    sbase print [FILE] [OPTIONS]")
     print("  Options:")
-    print("         -n   (Add line Numbers to the rows)")
+    print("           -n   (Add line Numbers to the rows)")
     print("  Output:")
-    print("         Prints the code/text of any file")
-    print("         with syntax-highlighting.")
+    print("           Prints the code/text of any file")
+    print("           with syntax-highlighting.")
     print("")
 
 
@@ -290,30 +422,30 @@ def show_translate_usage():
     print(sc)
     print("")
     print("  Usage:")
-    print("         seleniumbase translate [SB_FILE.py] [LANG] [ACTION]")
-    print("         OR:    sbase translate [SB_FILE.py] [LANG] [ACTION]")
+    print("           seleniumbase translate [SB_FILE.py] [LANG] [ACTION]")
+    print("           OR:    sbase translate [SB_FILE.py] [LANG] [ACTION]")
     print("  Languages:")
-    print("         --en / --English    |    --zh / --Chinese")
-    print("         --nl / --Dutch      |    --fr / --French")
-    print("         --it / --Italian    |    --ja / --Japanese")
-    print("         --ko / --Korean     |    --pt / --Portuguese")
-    print("         --ru / --Russian    |    --es / --Spanish")
+    print("           --en / --English    |    --zh / --Chinese")
+    print("           --nl / --Dutch      |    --fr / --French")
+    print("           --it / --Italian    |    --ja / --Japanese")
+    print("           --ko / --Korean     |    --pt / --Portuguese")
+    print("           --ru / --Russian    |    --es / --Spanish")
     print("  Actions:")
-    print("         -p / --print  (Print translation output to the screen)")
-    print("         -o / --overwrite  (Overwrite the file being translated)")
-    print("         -c / --copy  (Copy the translation to a new .py file)")
+    print("           -p / --print  (Print translation output to the screen)")
+    print("           -o / --overwrite  (Overwrite the file being translated)")
+    print("           -c / --copy  (Copy the translation to a new .py file)")
     print("  Options:")
-    print("         -n  (include line Numbers when using the Print action)")
+    print("           -n  (include line Numbers when using the Print action)")
     print("  Output:")
-    print("         Translates a SeleniumBase Python file into the language")
-    print('         specified. Method calls and "import" lines get swapped.')
-    print("         Both a language and an action must be specified.")
-    print('         The "-p" action can be paired with one other action.')
-    print('         When running with "-c" (or "--copy"), the new file name')
-    print("         will be the original name appended with an underscore")
-    print("         plus the 2-letter language code of the new language.")
-    print('         (Example: Translating "test_1.py" into Japanese with')
-    print('          "-c" will create a new file called "test_1_ja.py".)')
+    print("           Translates a SeleniumBase Python file into the language")
+    print('           specified. Method calls and "import" lines get swapped.')
+    print("           Both a language and an action must be specified.")
+    print('           The "-p" action can be paired with one other action.')
+    print('           When running with "-c" (or "--copy"), the new file name')
+    print("           will be the original name appended with an underscore")
+    print("           plus the 2-letter language code of the new language.")
+    print('           (Example: Translating "test_1.py" into Japanese with')
+    print('            "-c" will create a new file called "test_1_ja.py".)')
     print("")
 
 
@@ -570,7 +702,8 @@ def show_methods():
     sbm += "*.get_attribute(selector, attribute) => Get element attribute.\n"
     sbm += "*.get_title() => Get the title of the current page.\n"
     sbm += "*.switch_to_frame(frame) => Switch into the iframe container.\n"
-    sbm += "*.switch_to_default_content() => Leave the iframe container.\n"
+    sbm += "*.switch_to_default_content() => Exit all iframe containers.\n"
+    sbm += "*.switch_to_parent_frame() => Exit from the current iframe.\n"
     sbm += "*.open_new_window() => Open a new window in the same browser.\n"
     sbm += "*.switch_to_window(window) => Switch to the browser window.\n"
     sbm += "*.switch_to_default_window() => Switch to the original window.\n"
@@ -627,6 +760,7 @@ def show_options():
     op += "--html=report.html  (Create a detailed pytest-html report.)\n"
     op += "--collect-only / --co  (Only show discovered tests. No run.)\n"
     op += "--co -q  (Only show full names of discovered tests. No run.)\n"
+    op += "-x  (Stop running tests after the first failure is reached.)\n"
     op += "--pdb  (Enter the Post Mortem Debug Mode after any test fails.)\n"
     op += "--trace  (Enter Debug Mode immediately after starting any test.)\n"
     op += "      | Debug Mode Commands  >>>   help / h: List all commands. |\n"
@@ -634,9 +768,9 @@ def show_options():
     op += "      |  return / r: Run until method returns. j: Jump to line. |\n"
     op += "      | where / w: Show stack spot. u: Up stack. d: Down stack. |\n"
     op += "      | longlist / ll: See code. dir(): List namespace objects. |\n"
-    op += "-x  (Stop running the tests after the first failure is reached.)\n"
-    op += "--archive-logs  (Archive old log files instead of deleting them.)\n"
+    op += "--recorder  (Record browser actions to generate test scripts.)\n"
     op += "--save-screenshot  (Save a screenshot at the end of each test.)\n"
+    op += "--archive-logs  (Archive old log files instead of deleting them.)\n"
     op += "--check-js  (Check for JavaScript errors after page loads.)\n"
     op += "--start-page=URL  (The browser start page when tests begin.)\n"
     op += "--agent=STRING  (Modify the web browser's User-Agent string.)\n"
@@ -666,6 +800,73 @@ def show_options():
     print("")
 
 
+def show_behave_options():
+    c1 = colorama.Fore.BLUE + colorama.Back.LIGHTCYAN_EX
+    c2 = colorama.Fore.BLUE + colorama.Back.LIGHTGREEN_EX
+    c3 = colorama.Fore.BLUE + colorama.Back.LIGHTYELLOW_EX
+    c4 = colorama.Fore.MAGENTA + colorama.Back.LIGHTYELLOW_EX
+    c5 = colorama.Fore.RED + colorama.Back.LIGHTYELLOW_EX
+    cr = colorama.Style.RESET_ALL
+    sc = "\n " + c2 + " ** " + c3 + " Behave CLI Options " + c2 + " ** " + cr
+    print(sc)
+    print("")
+    line = 'Here are some common "behave" options to use with SeleniumBase:'
+    line = c1 + line + cr
+    print(line)
+    line = '(Some options are Chromium-specific, e.g. "-D guest -D mobile")'
+    print(line)
+    op = "\n"
+    op += '-D browser=BROWSER  (The web browser to use. Default is "chrome")\n'
+    op += "-D headless  (Run tests headlessly. Default mode on Linux OS.)\n"
+    op += "-D demo  (Slow down and visually see test actions as they occur.)\n"
+    op += "-D slow  (Slow down the automation. Faster than using Demo Mode.)\n"
+    op += "-D reuse-session / -D rs  (Reuse browser session between tests.)\n"
+    op += "-D crumbs  (Clear all cookies between tests reusing a session.)\n"
+    op += "-D maximize  (Start tests with the web browser window maximized.)\n"
+    op += "-D dashboard  (Enable SeleniumBase's Dashboard at dashboard.html)\n"
+    op += "-D incognito  (Enable Chromium's Incognito mode.)\n"
+    op += "-D guest  (Enable Chromium's Guest mode.)\n"
+    op += "--no-snippets / -q  (Quiet mode. Don't print snippets.)\n"
+    op += "--dry-run / -d  (Dry run. Only show discovered tests.)\n"
+    op += "--stop  (Stop running tests after the first failure is reached.)\n"
+    op += "-D pdb  (Enter the Post Mortem Debug Mode after any test fails.)\n"
+    op += "      | Debug Mode Commands  >>>   help / h: List all commands. |\n"
+    op += "      |   n: Next line of method. s: Step through. c: Continue. |\n"
+    op += "      |  return / r: Run until method returns. j: Jump to line. |\n"
+    op += "      | where / w: Show stack spot. u: Up stack. d: Down stack. |\n"
+    op += "      | longlist / ll: See code. dir(): List namespace objects. |\n"
+    op += "-D recorder  (Record browser actions to generate test scripts.)\n"
+    op += "-D save-screenshot  (Save a screenshot at the end of each test.)\n"
+    op += "-D archive-logs  (Archive log files instead of deleting them.)\n"
+    op += "-D check-js  (Check for JavaScript errors after page loads.)\n"
+    op += "-D start-page=URL  (The browser start page when tests begin.)\n"
+    op += "-D agent=STRING  (Modify the web browser's User-Agent string.)\n"
+    op += "-D mobile  (Use Chromium's mobile device emulator during tests.)\n"
+    op += '-D metrics=STRING  (Set mobile "CSSWidth,CSSHeight,PixelRatio".)\n'
+    op += "-D ad-block  (Block some types of display ads after page loads.)\n"
+    op += "-D settings-file=FILE  (Override default SeleniumBase settings.)\n"
+    op += '-D env=ENV  (Set the test env. Access using "self.env" in tests.)\n'
+    op += '-D data=DATA  (Extra test data. Access using "self.data".)\n'
+    op += "-D disable-csp  (Disable the Content Security Policy of sites.)\n"
+    op += "-D server=SERVER  (The Selenium Grid server/IP used for tests.)\n"
+    op += "-D port=PORT  (The Selenium Grid port used by the test server.)\n"
+    op += "-D proxy=SERVER:PORT  (Connect to a proxy server:port for tests.)\n"
+    op += "-D proxy=USER:PASS@SERVER:PORT  (Use authenticated proxy server.)\n"
+    op += cr
+    op = op.replace("\n-", "\n" + c1 + "-").replace("  (", cr + "  (")
+    op = op.replace(" / -", cr + " / " + c1 + "-")
+    op = op.replace("=", c2 + "=" + c3)
+    op = op.replace(" | ", " |" + c3 + " ").replace("|\n", cr + "|\n")
+    op = op.replace(": ", c5 + ":" + c3 + " ")
+    op = op.replace("Debug Mode Commands", c5 + "Debug Mode Commands" + c3)
+    op = op.replace(">>>", c4 + ">>>" + c3)
+    print(op)
+    line = "For the full list of " + c2 + "command-line options" + cr
+    line += ', type: "' + c3 + "behave" + cr + " " + c1 + "--help" + cr + '".'
+    print(line)
+    print("")
+
+
 def show_detailed_help():
     c2 = colorama.Fore.BLUE + colorama.Back.LIGHTGREEN_EX
     c3 = colorama.Fore.BLUE + colorama.Back.LIGHTYELLOW_EX
@@ -675,8 +876,13 @@ def show_detailed_help():
     print(c6 + "            " + c2 + "  Commands:  " + c6 + "            ")
     print(cr)
     show_install_usage()
+    show_commander_usage()
+    show_behave_gui_usage()
     show_mkdir_usage()
     show_mkfile_usage()
+    show_mkrec_usage()
+    show_codegen_usage()
+    show_recorder_usage()
     show_mkpres_usage()
     show_mkchart_usage()
     show_convert_usage()
@@ -709,7 +915,7 @@ def main():
         command_args = sys.argv[2:]
     command = command.lower()
 
-    if command == "install":
+    if command == "get" or command == "install":
         if len(command_args) >= 1:
             from seleniumbase.console_scripts import sb_install
 
@@ -717,6 +923,36 @@ def main():
         else:
             show_basic_usage()
             show_install_usage()
+    elif command == "commander" or command == "gui":
+        from seleniumbase.console_scripts import sb_commander
+
+        sb_commander.main()
+    elif command == "behave-gui" or command == "gui-behave":
+        from seleniumbase.console_scripts import sb_behave_gui
+
+        sb_behave_gui.main()
+    elif (
+        command == "recorder"
+        or (command == "record" and len(command_args) == 0)
+    ):
+        from seleniumbase.console_scripts import sb_recorder
+
+        sb_recorder.main()
+    elif (
+        command == "mkrec"
+        or command == "codegen"
+        or (command == "record" and len(command_args) >= 1)
+    ):
+        if len(command_args) >= 1:
+            from seleniumbase.console_scripts import sb_mkrec
+
+            sb_mkrec.main()
+        else:
+            show_basic_usage()
+            if command == "codegen":
+                show_codegen_usage()
+            else:
+                show_mkrec_usage()
     elif command == "mkdir":
         if len(command_args) >= 1:
             from seleniumbase.console_scripts import sb_mkdir
@@ -759,14 +995,6 @@ def main():
             show_convert_usage()
     elif command == "print":
         if len(command_args) >= 1:
-            if sys.version_info[0] == 2:
-                c5 = colorama.Fore.RED + colorama.Back.LIGHTYELLOW_EX
-                cr = colorama.Style.RESET_ALL
-                msg = '"sbase print" does NOT support Python 2! '
-                msg += 'Try using the Unix "cat" command instead!'
-                message = "\n" + c5 + msg + cr + "\n"
-                print("")
-                raise Exception(message)
             from seleniumbase.console_scripts import sb_print
 
             sb_print.main()
@@ -878,12 +1106,34 @@ def main():
         show_methods()
     elif command == "options" or command == "--options":
         show_options()
+    elif command == "behave-options" or command == "--behave-options":
+        show_behave_options()
     elif command == "help" or command == "--help":
         if len(command_args) >= 1:
-            if command_args[0] == "install":
+            if command_args[0] == "get":
                 print("")
                 show_install_usage()
                 return
+            elif command_args[0] == "install":
+                print("")
+                show_install_usage()
+                return
+            elif command_args[0] == "commander":
+                print("")
+                show_commander_usage()
+                return
+            elif command_args[0] == "gui":
+                print("")
+                show_commander_usage()
+                return
+            elif command_args[0] == "behave-gui":
+                print("")
+                show_behave_gui_usage()
+                return
+            elif command_args[0] == "gui-behave":
+                print("")
+                show_behave_gui_usage()
+                return
             elif command_args[0] == "mkdir":
                 print("")
                 show_mkdir_usage()
@@ -892,6 +1142,18 @@ def main():
                 print("")
                 show_mkfile_usage()
                 return
+            elif command_args[0] == "mkrec":
+                print("")
+                show_mkrec_usage()
+                return
+            elif command_args[0] == "codegen":
+                print("")
+                show_codegen_usage()
+                return
+            elif command_args[0] == "recorder":
+                print("")
+                show_recorder_usage()
+                return
             elif command_args[0] == "mkpres":
                 print("")
                 show_mkpres_usage()
