@@ -1,31 +1,33 @@
 """
-Installs the specified web driver.
+Downloads the specified webdriver to "seleniumbase/drivers/"
 
 Usage:
-        sbase install {chromedriver|geckodriver|edgedriver|
-                       iedriver|operadriver} [OPTIONS]
+         sbase get {chromedriver|geckodriver|edgedriver|
+                    iedriver|operadriver} [OPTIONS]
 Options:
-        VERSION         Specify the version.
-                        (Default chromedriver version = 2.44)
-                        Use "latest" for the latest version.
-        -p OR --path    Also copy the driver to /usr/local/bin
-Example:
-        sbase install chromedriver
-        sbase install geckodriver
-        sbase install edgedriver
-        sbase install chromedriver 91.0.4472.101
-        sbase install chromedriver 91
-        sbase install chromedriver latest
-        sbase install chromedriver -p
-        sbase install chromedriver latest -p
-        sbase install edgedriver 91.0.864.67
+         VERSION         Specify the version.
+                         (Default chromedriver = 72.0.3626.69)
+                         Use "latest" for the latest version.
+                         Use "latest-1" for one less than that.
+         -p OR --path    Also copy the driver to /usr/local/bin
+Examples:
+         sbase get chromedriver
+         sbase get geckodriver
+         sbase get edgedriver
+         sbase get chromedriver 102.0.5005.61
+         sbase get chromedriver 102
+         sbase get chromedriver latest
+         sbase get chromedriver latest-1  # (Latest minus one)
+         sbase get chromedriver -p
+         sbase get chromedriver latest -p
+         sbase get edgedriver 102.0.1245.44
 Output:
-        Installs the chosen webdriver to seleniumbase/drivers/
-        (chromedriver is required for Chrome automation)
-        (geckodriver is required for Firefox automation)
-        (edgedriver is required for MS Edge automation)
-        (operadriver is required for Opera Browser automation)
-        (iedriver is required for Internet Explorer automation)
+         Downloads the chosen webdriver to seleniumbase/drivers
+         (chromedriver is required for Chrome automation)
+         (geckodriver is required for Firefox automation)
+         (edgedriver is required for MS Edge automation)
+         (operadriver is required for Opera Browser automation)
+         (iedriver is required for InternetExplorer automation)
 """
 
 import colorama
@@ -42,33 +44,42 @@ from seleniumbase import drivers  # webdriver storage folder for SeleniumBase
 urllib3.disable_warnings()
 DRIVER_DIR = os.path.dirname(os.path.realpath(drivers.__file__))
 LOCAL_PATH = "/usr/local/bin/"  # On Mac and Linux systems
-DEFAULT_CHROMEDRIVER_VERSION = "2.44"  # (Specify "latest" to get the latest)
-DEFAULT_GECKODRIVER_VERSION = "v0.29.1"
-DEFAULT_EDGEDRIVER_VERSION = "89.0.774.54"  # (Looks for LATEST_STABLE first)
-DEFAULT_OPERADRIVER_VERSION = "v.88.0.4324.104"
+DEFAULT_CHROMEDRIVER_VERSION = "72.0.3626.69"  # (Specify "latest" for latest)
+DEFAULT_GECKODRIVER_VERSION = "v0.31.0"
+DEFAULT_EDGEDRIVER_VERSION = "102.0.1245.44"  # (Looks for LATEST_STABLE first)
+DEFAULT_OPERADRIVER_VERSION = "v.96.0.4664.45"
 
 
 def invalid_run_command():
-    exp = "  ** install **\n\n"
+    exp = "  ** get / install **\n\n"
     exp += "  Usage:\n"
-    exp += "          seleniumbase install [DRIVER_NAME] [OPTIONS]\n"
-    exp += "              (Drivers: chromedriver, geckodriver, edgedriver,\n"
-    exp += "                        iedriver, operadriver)\n"
+    exp += "           seleniumbase install [DRIVER] [OPTIONS]\n"
+    exp += "           OR     sbase install [DRIVER] [OPTIONS]\n"
+    exp += "           OR  seleniumbase get [DRIVER] [OPTIONS]\n"
+    exp += "           OR         sbase get [DRIVER] [OPTIONS]\n"
+    exp += "                (Drivers: chromedriver, geckodriver, edgedriver,\n"
+    exp += "                          iedriver, operadriver)\n"
     exp += "  Options:\n"
-    exp += "          VERSION         Specify the version.\n"
-    exp += "                          (Default chromedriver version = 2.44)\n"
-    exp += '                          Use "latest" for the latest version.\n'
-    exp += "          -p OR --path    Also copy the driver to /usr/local/bin\n"
-    exp += "  Example:\n"
-    exp += "          seleniumbase install chromedriver\n"
-    exp += "          seleniumbase install geckodriver\n"
-    exp += "          seleniumbase install chromedriver 89\n"
-    exp += "          seleniumbase install chromedriver 89.0.4389.23\n"
-    exp += "          seleniumbase install chromedriver latest\n"
-    exp += "          seleniumbase install chromedriver -p\n"
-    exp += "          seleniumbase install chromedriver latest -p\n"
+    exp += "           VERSION        Specify the version.\n"
+    exp += "                           (Default chromedriver = 72.0.3626.69.\n"
+    exp += '                            Use "latest" for the latest version.\n'
+    exp += "                            For chromedriver, you can also use\n"
+    exp += "                            the major version integer\n"
+    exp += '                            or "latest-1" for 1 less than that.)\n'
+    exp += "           -p OR --path   Also copy the driver to /usr/local/bin\n"
+    exp += "  Examples:\n"
+    exp += "           sbase get chromedriver\n"
+    exp += "           sbase get geckodriver\n"
+    exp += "           sbase get edgedriver\n"
+    exp += "           sbase get chromedriver 102\n"
+    exp += "           sbase get chromedriver 102.0.5005.61\n"
+    exp += "           sbase get chromedriver latest\n"
+    exp += "           sbase get chromedriver latest-1\n"
+    exp += "           sbase get chromedriver -p\n"
+    exp += "           sbase get chromedriver latest -p\n"
+    exp += "           sbase get edgedriver 102.0.1245.44\n"
     exp += "  Output:\n"
-    exp += "          Installs the chosen webdriver to seleniumbase/drivers/\n"
+    exp += "          Downloads the chosen webdriver to seleniumbase/drivers\n"
     exp += "          (chromedriver is required for Chrome automation)\n"
     exp += "          (geckodriver is required for Firefox automation)\n"
     exp += "          (edgedriver is required for Microsoft Edge automation)\n"
@@ -96,22 +107,45 @@ def requests_get(url):
     return response
 
 
+def requests_get_with_retry(url):
+    response = None
+    try:
+        response = requests.get(url)
+    except Exception:
+        import time
+
+        time.sleep(0.75)
+        response = requests.get(url)
+    return response
+
+
 def main(override=None):
-    if override == "chromedriver":
-        sys.argv = ["seleniumbase", "install", "chromedriver"]
-    elif override == "edgedriver":
-        sys.argv = ["seleniumbase", "install", "edgedriver"]
-    elif override == "geckodriver":
-        sys.argv = ["seleniumbase", "install", "geckodriver"]
-    elif override == "iedriver":
-        sys.argv = ["seleniumbase", "install", "iedriver"]
+    if override:
+        if override == "chromedriver":
+            sys.argv = ["seleniumbase", "get", "chromedriver"]
+        elif override.startswith("chromedriver "):
+            extra = override.split("chromedriver ")[1]
+            sys.argv = ["seleniumbase", "get", "chromedriver", extra]
+        elif override == "edgedriver":
+            sys.argv = ["seleniumbase", "get", "edgedriver"]
+        elif override.startswith("edgedriver "):
+            extra = override.split("edgedriver ")[1]
+            sys.argv = ["seleniumbase", "get", "edgedriver", extra]
+        elif override == "geckodriver":
+            sys.argv = ["seleniumbase", "get", "geckodriver"]
+        elif override.startswith("geckodriver "):
+            extra = override.split("geckodriver ")[1]
+            sys.argv = ["seleniumbase", "get", "geckodriver", extra]
+        elif override == "iedriver":
+            sys.argv = ["seleniumbase", "get", "iedriver"]
+        elif override.startswith("iedriver "):
+            extra = override.split("iedriver ")[1]
+            sys.argv = ["seleniumbase", "get", "iedriver", extra]
 
     num_args = len(sys.argv)
     if (
-        sys.argv[0].split("/")[-1].lower() == "seleniumbase"
-        or (sys.argv[0].split("\\")[-1].lower() == "seleniumbase")
-        or (sys.argv[0].split("/")[-1].lower() == "sbase")
-        or (sys.argv[0].split("\\")[-1].lower() == "sbase")
+        "sbase" in sys.argv[0].lower()
+        or ("seleniumbase" in sys.argv[0].lower())
     ):
         if num_args < 3 or num_args > 5:
             invalid_run_command()
@@ -153,12 +187,15 @@ def main(override=None):
         use_version = DEFAULT_CHROMEDRIVER_VERSION
         get_latest = False
         get_v_latest = False
+        get_latest_minus_one = False
         if num_args == 4 or num_args == 5:
             if "-p" not in sys.argv[3].lower():
                 use_version = sys.argv[3]
                 uv_low = use_version.lower()
                 if uv_low == "latest":
                     get_latest = True
+                elif uv_low == "latest-1":
+                    get_latest_minus_one = True
                 elif len(uv_low) < 4 and uv_low.isdigit() and int(uv_low) > 69:
                     get_v_latest = True
             else:
@@ -181,12 +218,15 @@ def main(override=None):
                 "Cannot determine which version of chromedriver to download!"
             )
         found_chromedriver = False
-        if get_latest:
+        if get_latest or get_latest_minus_one:
             url_request = requests_get(last)
             if url_request.ok:
                 found_chromedriver = True
                 use_version = url_request.text
-        elif get_v_latest:
+                if get_latest_minus_one:
+                    get_v_latest = True
+                    use_version = str(int(use_version.split(".")[0]) - 1)
+        if get_v_latest:
             url_req = requests_get(last)
             if url_req.ok:
                 latest_version = url_req.text
@@ -215,7 +255,15 @@ def main(override=None):
             if get_latest:
                 p_version = p_version + " " + c2 + "(Latest)" + cr
             else:
-                not_latest = c5 + "(" + c4 + "NOT Latest" + c5 + ")" + cr
+                n_l_s = "NOT Latest"
+                try:
+                    int_use_version = int(use_version.split(".")[0])
+                    int_latest_version = int(latest_version.split(".")[0])
+                    if int_use_version > int_latest_version:
+                        n_l_s = "NOT Latest Stable"
+                except Exception:
+                    pass
+                not_latest = c5 + "(" + c4 + n_l_s + c5 + ")" + cr
                 p_version = p_version + " " + not_latest
             msg = c2 + "chromedriver version for download" + cr
             print("\n*** %s = %s" % (msg, p_version))
@@ -224,7 +272,7 @@ def main(override=None):
         if not get_latest:
             to_upgrade = " " + c3 + "To upgrade" + cr
             run_this = c3 + "run this" + cr
-            install_sb = c6 + "sbase install chromedriver latest" + cr
+            install_sb = c6 + "sbase get chromedriver latest" + cr
             print("\n %s to the latest version of chromedriver," % to_upgrade)
             print("   %s: >>> %s" % (run_this, install_sb))
             print("  (Requires the latest version of Chrome installed)")
@@ -308,28 +356,41 @@ def main(override=None):
             else:
                 invalid_run_command()
         if get_latest:
-            url_request = requests.get(last)
+            url_request = requests_get_with_retry(last)
             if url_request.ok:
                 use_version = url_request.text.split("\r")[0].split("\n")[0]
+                use_version = use_version.split(".")[0]
             else:
                 use_version = DEFAULT_EDGEDRIVER_VERSION
+        suffix = None
         if "win64" in sys_plat or "x64" in sys_plat:
             file_name = "edgedriver_win64.zip"
+            suffix = "WINDOWS"
         elif "win32" in sys_plat or "x86" in sys_plat:
             file_name = "edgedriver_win32.zip"
+            suffix = "WINDOWS"
         elif "darwin" in sys_plat:
             file_name = "edgedriver_mac64.zip"
+            suffix = "MACOS"
+        elif "linux" in sys_plat:
+            file_name = "edgedriver_linux64.zip"
+            suffix = "LINUX"
         else:
             raise Exception(
-                "Sorry! Microsoft WebDriver / EdgeDriver is "
-                "only for Windows or Mac operating systems!"
+                "Cannot determine which version of EdgeDriver to download!"
             )
-        download_url = "https://msedgedriver.azureedge.net/" "%s/%s" % (
+        if use_version.isdigit():
+            edgedriver_st = "https://msedgedriver.azureedge.net/LATEST_RELEASE"
+            use_version = "%s_%s_%s" % (edgedriver_st, use_version, suffix)
+            url_request = requests_get_with_retry(use_version)
+            if url_request.ok:
+                use_version = url_request.text.split("\r")[0].split("\n")[0]
+        download_url = "https://msedgedriver.azureedge.net/%s/%s" % (
             use_version,
             file_name,
         )
         if not get_latest and not use_version == DEFAULT_EDGEDRIVER_VERSION:
-            url_request = requests.get(download_url)
+            url_request = requests_get_with_retry(download_url)
             if not url_request.ok:
                 raise Exception(
                     "Could not find version [%s] of EdgeDriver!" % use_version
@@ -361,7 +422,7 @@ def main(override=None):
             "releases/download/"
             "%s/%s" % (headless_ie_version, headless_ie_file_name)
         )
-        url_request = requests.get(headless_ie_url)
+        url_request = requests_get_with_retry(headless_ie_url)
         if url_request.ok:
             headless_ie_exists = True
             msg = c2 + "HeadlessIEDriver version for download" + cr
@@ -440,7 +501,7 @@ def main(override=None):
 
     file_path = downloads_folder + "/" + file_name
     if not os.path.exists(downloads_folder):
-        os.mkdir(downloads_folder)
+        os.makedirs(downloads_folder)
 
     if headless_ie_exists:
         headless_ie_file_path = downloads_folder + "/" + headless_ie_file_name
@@ -448,7 +509,7 @@ def main(override=None):
             "\nDownloading %s from:\n%s ..."
             % (headless_ie_file_name, headless_ie_url)
         )
-        remote_file = requests.get(headless_ie_url)
+        remote_file = requests_get_with_retry(headless_ie_url)
         with open(headless_ie_file_path, "wb") as file:
             file.write(remote_file.content)
         print("Download Complete!\n")
@@ -523,7 +584,7 @@ def main(override=None):
         print("%s[%s] is now ready for use!%s" % (c1, driver_file, cr))
 
     print("\nDownloading %s from:\n%s ..." % (file_name, download_url))
-    remote_file = requests.get(download_url)
+    remote_file = requests_get_with_retry(download_url)
     with open(file_path, "wb") as file:
         file.write(remote_file.content)
     print("Download Complete!\n")
@@ -564,6 +625,7 @@ def main(override=None):
                 # Mac / Linux
                 expected_contents = [
                     "Driver_Notes/",
+                    "Driver_Notes/EULA",
                     "Driver_Notes/LICENSE",
                     "Driver_Notes/credits.html",
                     "msedgedriver",
@@ -574,6 +636,7 @@ def main(override=None):
                 expected_contents = [
                     "Driver_Notes/",
                     "Driver_Notes/credits.html",
+                    "Driver_Notes/EULA",
                     "Driver_Notes/LICENSE",
                     "msedgedriver.exe",
                 ]
@@ -616,6 +679,7 @@ def main(override=None):
             print("Unzip Complete!\n")
             to_remove = [
                 "%s/Driver_Notes/credits.html" % downloads_folder,
+                "%s/Driver_Notes/EULA" % downloads_folder,
                 "%s/Driver_Notes/LICENSE" % downloads_folder,
             ]
             for file_to_remove in to_remove:
@@ -631,6 +695,11 @@ def main(override=None):
             print("Making [%s %s] executable ..." % (driver_file, use_version))
             make_executable(driver_path)
             print("%s[%s] is now ready for use!%s" % (c1, driver_file, cr))
+            if copy_to_path and os.path.exists(LOCAL_PATH):
+                path_file = LOCAL_PATH + f_name
+                shutil.copyfile(new_file, path_file)
+                make_executable(path_file)
+                print("Also copied to: %s%s%s" % (c3, path_file, cr))
             print("")
         elif name == "operadriver":
             if len(contents) > 3:
