@@ -162,10 +162,17 @@ def main():
     file.close()
 
     data = []
+    data.append("[flake8]")
+    data.append("exclude=recordings,temp")
+    data.append("")
     data.append("[nosetests]")
     data.append("nocapture=1")
     data.append("logging-level=INFO")
     data.append("")
+    data.append("[behave]")
+    data.append("show_skipped=false")
+    data.append("show_timings=false")
+    data.append("")
     data.append("[bdist_wheel]")
     data.append("universal=1")
     file_path = "%s/%s" % (dir_name, "setup.cfg")
@@ -238,6 +245,7 @@ def main():
     data.append("msedgedriver")
     data.append("operadriver")
     data.append("MicrosoftWebDriver.exe")
+    data.append("headless_ie_selenium.exe")
     data.append("IEDriverServer.exe")
     data.append("chromedriver.exe")
     data.append("geckodriver.exe")
@@ -249,6 +257,7 @@ def main():
     data.append("archived_logs")
     data.append("geckodriver.log")
     data.append("pytestdebug.log")
+    data.append("reports/*.xml")
     data.append("latest_report")
     data.append("report_archives")
     data.append("archived_reports")
@@ -268,7 +277,9 @@ def main():
     data.append("tours_exported")
     data.append("images_exported")
     data.append("saved_cookies")
+    data.append("recordings")
     data.append("visual_baseline")
+    data.append(".DS_Store")
     data.append("selenium-server-standalone.jar")
     data.append("proxy.zip")
     data.append("proxy.lock")
@@ -287,6 +298,18 @@ def main():
     file.close()
 
     if basic:
+        data = []
+        data.append("  %s/" % dir_name)
+        data.append("  ├── __init__.py")
+        data.append("  ├── pytest.ini")
+        data.append("  ├── requirements.txt")
+        data.append("  └── setup.cfg")
+        file_path = "%s/%s" % (dir_name, "outline.rst")
+        file = codecs.open(file_path, "w+", "utf-8")
+        file.writelines("\r\n".join(data))
+        file.close()
+        os.system("sbase print %s -n" % file_path)
+        os.remove(file_path)
         success = (
             "\n" + c1 + '* Directory "' + dir_name + '" was created '
             "with config files! *" + cr + "\n"
@@ -299,20 +322,29 @@ def main():
     data.append("")
     data.append("")
     data.append("class MyTestClass(BaseCase):")
-    data.append("    def test_basics(self):")
-    data.append('        url = "https://store.xkcd.com/collections/posters"')
-    data.append("        self.open(url)")
-    data.append('        self.type(\'input[name="q"]\', "xkcd book")')
-    data.append("        self.click('input[value=\"Search\"]')")
-    data.append('        self.assert_text("xkcd: volume 0", "h3")')
-    data.append('        self.open("https://xkcd.com/353/")')
-    data.append('        self.assert_title("xkcd: Python")')
-    data.append("        self.assert_element('img[alt=\"Python\"]')")
-    data.append("        self.click('a[rel=\"license\"]')")
-    data.append('        self.assert_text("free to copy and reuse")')
-    data.append("        self.go_back()")
-    data.append('        self.click_link("About")')
-    data.append('        self.assert_exact_text("xkcd.com", "h2")')
+    data.append("    def test_swag_labs(self):")
+    data.append('        self.open("https://www.saucedemo.com")')
+    data.append('        self.type("#user-name", "standard_user")')
+    data.append('        self.type("#password", "secret_sauce\\n")')
+    data.append('        self.assert_element("div.inventory_list")')
+    data.append('        self.assert_text("PRODUCTS", "span.title")')
+    data.append("        self.click('button[name*=\"backpack\"]')")
+    data.append('        self.click("#shopping_cart_container a")')
+    data.append('        self.assert_text("YOUR CART", "span.title")')
+    data.append('        self.assert_text("Backpack", "div.cart_item")')
+    data.append('        self.click("button#checkout")')
+    data.append('        self.type("#first-name", "SeleniumBase")')
+    data.append('        self.type("#last-name", "Automation")')
+    data.append('        self.type("#postal-code", "77123")')
+    data.append('        self.click("input#continue")')
+    data.append('        self.assert_text("CHECKOUT: OVERVIEW")')
+    data.append('        self.assert_text("Backpack", "div.cart_item")')
+    data.append('        self.click("button#finish")')
+    data.append(
+        '        self.assert_exact_text("THANK YOU FOR YOUR ORDER", "h2")'
+    )
+    data.append("        self.assert_element('img[alt=\"Pony Express\"]')")
+    data.append('        self.js_click("a#logout_sidebar_link")')
     data.append("")
     file_path = "%s/%s" % (dir_name, "my_first_test.py")
     file = codecs.open(file_path, "w+", "utf-8")
@@ -333,7 +365,12 @@ def main():
     data.append('        self.type("textarea.area1", "Testing Time!\\n")')
     data.append('        self.type(\'[name="preText2"]\', "Typing Text!")')
     data.append('        self.assert_text("Automation Practice", "h3")')
-    data.append('        self.hover_and_click("#myDropdown", "#dropOption2")')
+    data.append("        try:")
+    data.append("            self.hover_and_click(")
+    data.append('                "#myDropdown", "#dropOption2", timeout=1)')
+    data.append("        except Exception:")
+    data.append("            # If someone moves the mouse while the test runs")
+    data.append('            self.js_click("#dropOption2")')
     data.append('        self.assert_text("Link Two Selected", "h3")')
     data.append('        self.assert_text("This Text is Green", "#pText")')
     data.append('        self.click("#myButton")')
@@ -379,12 +416,20 @@ def main():
     data.append('        self.click(".fBox")')
     data.append('        self.assert_true(self.is_selected(".fBox"))')
     data.append("        self.switch_to_default_content()")
+    data.append(
+        '        self.assert_element_not_visible("div#drop2 img#logo")'
+    )
+    data.append('        self.drag_and_drop("img#logo", "div#drop2")')
+    data.append('        self.assert_element("div#drop2 img#logo")')
     data.append('        self.assert_link_text("seleniumbase.com")')
     data.append('        self.assert_link_text("SeleniumBase on GitHub")')
     data.append('        self.assert_link_text("seleniumbase.io")')
     data.append('        self.click_link("SeleniumBase Demo Page")')
     data.append('        self.assert_exact_text("Demo Page", "h1")')
     data.append('        self.highlight("h2")')
+    data.append("        self.demo_mode = True")
+    data.append('        self.type("input", "Have a Nice Day!")')
+    data.append('        self.assert_text("SeleniumBase", "h2")')
     data.append("")
     file_path = "%s/%s" % (dir_name, "test_demo_site.py")
     file = codecs.open(file_path, "w+", "utf-8")
@@ -392,16 +437,16 @@ def main():
     file.close()
 
     data = []
-    data.append("from seleniumbase import BaseCase")
     data.append("from parameterized import parameterized")
+    data.append("from seleniumbase import BaseCase")
     data.append("")
     data.append("")
     data.append("class GoogleTests(BaseCase):")
     data.append("    @parameterized.expand(")
     data.append("        [")
-    data.append('            ["pypi", "pypi.org"],')
+    data.append('            ["Download Python", "Download Python"],')
     data.append('            ["wikipedia", "wikipedia.org"],')
-    data.append('            ["seleniumbase", "seleniumbase/SeleniumBase"],')
+    data.append('            ["seleniumbase", "SeleniumBase"],')
     data.append("        ]")
     data.append("    )")
     data.append(
@@ -412,7 +457,6 @@ def main():
     data.append(
         '        self.type(\'input[title="Search"]\', search_term + "\\n")'
     )
-    data.append('        self.assert_element("#result-stats")')
     data.append('        self.assert_text(expected_text, "#search")')
     data.append("")
     file_path = "%s/%s" % (dir_name, "parameterized_test.py")
@@ -593,6 +637,8 @@ def main():
     file.close()
 
     data = []
+    data.append('""" Classic Page Object Model with BaseCase inheritance """')
+    data.append("")
     data.append("from seleniumbase import BaseCase")
     data.append("")
     data.append("")
@@ -620,6 +666,9 @@ def main():
     file.close()
 
     data = []
+    data.append('""" Classic Page Object Model with the "sb" fixture """')
+    data.append("")
+    data.append("")
     data.append("class LoginPage:")
     data.append("    def login_to_swag_labs(self, sb, username):")
     data.append('        sb.open("https://www.saucedemo.com/")')
@@ -631,7 +680,7 @@ def main():
     data.append("class MyTests:")
     data.append("    def test_swag_labs_login(self, sb):")
     data.append('        LoginPage().login_to_swag_labs(sb, "standard_user")')
-    data.append('        sb.assert_element("#inventory_container")')
+    data.append('        sb.assert_element("div.inventory_list")')
     data.append(
         "        sb.assert_element('div:contains(\"Sauce Labs Backpack\")')"
     )
@@ -641,6 +690,40 @@ def main():
     file.writelines("\r\n".join(data))
     file.close()
 
+    data = []
+    data.append("  %s/" % dir_name)
+    data.append("  ├── __init__.py")
+    data.append("  ├── my_first_test.py")
+    data.append("  ├── parameterized_test.py")
+    data.append("  ├── pytest.ini")
+    data.append("  ├── requirements.txt")
+    data.append("  ├── setup.cfg")
+    data.append("  ├── test_demo_site.py")
+    data.append("  └── boilerplates/")
+    data.append("      ├── __init__.py")
+    data.append("      ├── base_test_case.py")
+    data.append("      ├── boilerplate_test.py")
+    data.append("      ├── classic_obj_test.py")
+    data.append("      ├── page_objects.py")
+    data.append("      ├── sb_fixture_test.py")
+    data.append("      └── samples/")
+    data.append("          ├── __init__.py")
+    data.append("          ├── google_objects.py")
+    data.append("          ├── google_test.py")
+    data.append("          ├── sb_swag_test.py")
+    data.append("          └── swag_labs_test.py")
+    file_path = "%s/%s" % (dir_name, "outline.rst")
+    file = codecs.open(file_path, "w+", "utf-8")
+    file.writelines("\r\n".join(data))
+    file.close()
+    if " " not in file_path:
+        os.system("sbase print %s -n" % file_path)
+    elif '"' not in file_path:
+        os.system('sbase print "%s" -n' % file_path)
+    else:
+        os.system("sbase print '%s' -n" % file_path)
+    os.remove(file_path)
+
     success = (
         "\n" + c1 + '* Directory "' + dir_name + '" was created '
         "with config files and sample tests! *" + cr + "\n"
