@@ -89,6 +89,8 @@ def main():
         code_lang = "go"
     elif file_to_print.lower().endswith(".java"):
         code_lang = "java"
+    elif file_to_print.lower().endswith(".feature"):
+        code_lang = "gherkin"
     elif "." not in file_to_print:
         code_lang = "markdown"
     else:
@@ -114,17 +116,21 @@ def main():
     if help_me:
         invalid_run_command(invalid_cmd)
 
-    with open(file_to_print, "r", encoding="utf-8") as f:
-        all_code = f.read()
+    all_code = None
+    if sys.version_info[0] >= 3:
+        with open(file_to_print, "r", encoding="utf-8") as f:
+            all_code = f.read()
+    else:
+        with open(file_to_print, "r") as f:
+            all_code = f.read()
     all_code = all_code.replace("\t", "    ")
     code_lines = all_code.split("\n")
 
     console_width = None  # width of console output when running script
     used_width = None  # code_width and few spaces on right for padding
-    magic_console = None
-    magic_syntax = None
+    magic_syntax = None  # the syntax generated by rich.syntax.Syntax()
     try:
-        console_width = os.popen("stty size", "r").read().split()[1]
+        console_width = os.get_terminal_size()[0]
         if console_width:
             console_width = int(console_width)
     except Exception:
@@ -135,8 +141,7 @@ def main():
         use_rich = True
 
     if use_rich:
-        from rich.console import Console
-        from rich.syntax import Syntax
+        from seleniumbase.console_scripts import rich_helper
 
         the_code = "\n".join(code_lines)
         code_width = 1
@@ -566,22 +571,20 @@ def main():
         if console_width and (code_width + extra_r_spaces < console_width):
             used_width = code_width + extra_r_spaces
 
-        try:
-            if "🗺️" in the_code:
-                # Fix width of an emoji
-                the_code = the_code.replace("🗺️", "🗺️ ")
-        except Exception:
-            pass
+        the_code = rich_helper.fix_emoji_spacing(the_code)
+        the_theme = "monokai"
+        platform = sys.platform
+        if "win32" in platform or "win64" in platform or "x64" in platform:
+            the_theme = "abap"
 
-        magic_syntax = Syntax(
+        magic_syntax = rich_helper.process_syntax(
             the_code,
             code_lang,
-            theme="monokai",
+            theme=the_theme,
             line_numbers=line_numbers,
             code_width=used_width,
             word_wrap=word_wrap,
         )
-        magic_console = Console()
     # ----------------------------------------
     dash_length = 62  # May change
     if used_width and used_width + w < console_width:
@@ -591,22 +594,32 @@ def main():
     dashes = "-" * dash_length
     print(dashes)
     print_success = False
-    if use_rich and code_lang == "markdown":
-        try:
-            from rich.markdown import Markdown
-
-            markdown = Markdown(all_code)
-            markdown_console = Console()
-            markdown_console.print(markdown)  # noqa
-            print_success = True
-        except Exception:
-            pass
+    if use_rich and code_lang == "markdown" and not line_numbers:
+        all_code = rich_helper.fix_emoji_spacing(all_code)
+        all_code = all_code.replace("<br />", "\n")
+        all_code = all_code.replace('<p align="center">', "\n")
+        all_code = all_code.replace('<p align="left">', "\n")
+        all_code = all_code.replace('<p align="right">', "\n")
+        all_code = all_code.replace("<p>", "\n")
+        all_code = all_code.replace("</p>", "\n")
+        if "<b>*" not in all_code and "*<b>" not in all_code:
+            if "</b>*" not in all_code and "*</b>" not in all_code:
+                all_code = all_code.replace("<b>", "**")
+                all_code = all_code.replace("</b>", "**")
+        if "<code>`" not in all_code and "`<code>" not in all_code:
+            if "</code>`" not in all_code and "`</code>" not in all_code:
+                all_code = all_code.replace("<code>", "``")
+                all_code = all_code.replace("</code>", "``")
+        # Display ALL <h> tags as an <h1> because the font size is fixed
+        all_code = all_code.replace("\n<h1>", "\n# ").replace("</h1>", "")
+        all_code = all_code.replace("\n<h2>", "\n# ").replace("</h2>", "")
+        all_code = all_code.replace("\n<h3>", "\n# ").replace("</h3>", "")
+        all_code = all_code.replace("\n<h4>", "\n# ").replace("</h4>", "")
+        print_success = rich_helper.display_markdown(all_code)
+        if all_code.endswith("\n"):
+            print()  # Because "rich" skips the last line if new-line
     elif use_rich and magic_syntax:
-        try:
-            magic_console.print(magic_syntax)  # noqa
-            print_success = True
-        except Exception:
-            pass
+        print_success = rich_helper.display_code(magic_syntax)
     if not use_rich or not magic_syntax or not print_success:
         for line in code_lines:
             print(line)
