@@ -4,6 +4,7 @@ import os
 import shutil
 import sys
 import time
+from seleniumbase import config as sb_config
 from seleniumbase.config import settings
 from seleniumbase.fixtures import constants
 
@@ -31,7 +32,7 @@ def log_screenshot(test_logpath, driver, screenshot=None, get=False):
 
 
 def get_master_time():
-    """ Returns (timestamp, the_date, the_time) """
+    """Returns (timestamp, the_date, the_time)"""
     import datetime
 
     timestamp = str(int(time.time())) + "  (Unix Timestamp)"
@@ -65,15 +66,72 @@ def get_master_time():
     return timestamp, the_date, the_time
 
 
+def get_browser_version(driver):
+    driver_capabilities = driver.capabilities
+    if "version" in driver_capabilities:
+        browser_version = driver_capabilities["version"]
+    else:
+        browser_version = driver_capabilities["browserVersion"]
+    return browser_version
+
+
+def get_driver_name_and_version(driver, browser):
+    if driver.capabilities["browserName"].lower() == "chrome":
+        cap_dict = driver.capabilities["chrome"]
+        return ("chromedriver", cap_dict["chromedriverVersion"].split(" ")[0])
+    elif driver.capabilities["browserName"].lower() == "msedge":
+        cap_dict = driver.capabilities["msedge"]
+        return ("msedgedriver", cap_dict["msedgedriverVersion"].split(" ")[0])
+    elif driver.capabilities["browserName"].lower() == "opera":
+        cap_dict = driver.capabilities["opera"]
+        return ("operadriver", cap_dict["operadriverVersion"].split(" ")[0])
+    elif driver.capabilities["browserName"].lower() == "firefox":
+        return ("geckodriver", driver.capabilities["moz:geckodriverVersion"])
+    elif browser == "safari":
+        return ("safaridriver", get_browser_version(driver))
+    elif browser == "ie":
+        return ("iedriver", get_browser_version(driver))
+    else:
+        return None
+
+
 def log_test_failure_data(test, test_logpath, driver, browser, url=None):
     import traceback
 
+    browser_displayed = browser
+    driver_displayed = None
+    browser_version = None
+    driver_version = None
+    driver_name = None
+    try:
+        browser_version = get_browser_version(driver)
+    except Exception:
+        pass
+    try:
+        driver_name, driver_version = get_driver_name_and_version(
+            driver, browser
+        )
+    except Exception:
+        pass
+    if browser_version:
+        headless = ""
+        if test.headless and browser in ["chrome", "edge", "firefox"]:
+            headless = " / headless"
+        browser_displayed = "%s (%s%s)" % (browser, browser_version, headless)
+        if driver_name and driver_version:
+            driver_displayed = "%s (%s)" % (driver_name, driver_version)
+    if not browser_version:
+        browser_displayed = browser
+        driver_displayed = "(Unknown Driver)"
+    if not driver_displayed:
+        driver_displayed = "(Unknown Driver)"
     basic_info_name = settings.BASIC_INFO_NAME
     basic_file_path = "%s/%s" % (test_logpath, basic_info_name)
     if url:
         last_page = url
     else:
         last_page = get_last_page(driver)
+    sb_config._fail_page = last_page
     timestamp, the_date, the_time = get_master_time()
     test_id = get_test_id(test)  # pytest runnable display_id (with the "::")
     data_to_save = []
@@ -82,7 +140,8 @@ def log_test_failure_data(test, test_logpath, driver, browser, url=None):
         "--------------------------------------------------------------------"
     )
     data_to_save.append("Last Page: %s" % last_page)
-    data_to_save.append("  Browser: %s" % browser)
+    data_to_save.append("  Browser: %s" % browser_displayed)
+    data_to_save.append("   Driver: %s" % driver_displayed)
     data_to_save.append("Timestamp: %s" % timestamp)
     data_to_save.append("     Date: %s" % the_date)
     data_to_save.append("     Time: %s" % the_time)
@@ -108,31 +167,46 @@ def log_test_failure_data(test, test_logpath, driver, browser, url=None):
         data_to_save.append("Exception: " + str(exc_message))
     else:
         the_traceback = None
-        the_traceback = "".join(
-            traceback.format_exception(
-                sys.exc_info()[0],
-                sys.exc_info()[1],
-                sys.exc_info()[2],
+        if hasattr(test, "is_behave") and test.is_behave:
+            if sb_config.behave_scenario.status.name == "failed":
+                if sb_config.behave_step.error_message:
+                    the_traceback = sb_config.behave_step.error_message
+        else:
+            the_traceback = "".join(
+                traceback.format_exception(
+                    sys.exc_info()[0],
+                    sys.exc_info()[1],
+                    sys.exc_info()[2],
+                )
             )
-        )
         if (
             not the_traceback
             or len(str(the_traceback)) < 30
             or the_traceback.endswith("StopIteration\n")
         ):
             good_stack = []
-            the_stacks = traceback.format_list(
-                traceback.extract_tb(sys.last_traceback)
-            )
+            the_stacks = []
+            if hasattr(sys, "last_traceback"):
+                the_stacks = traceback.format_list(
+                    traceback.extract_tb(sys.last_traceback)
+                )
+            else:
+                message = None
+                if hasattr(test, "is_behave") and test.is_behave:
+                    message = "Behave step was not implemented or skipped!"
+                else:
+                    message = "Traceback not found!"
+                the_stacks = [message]
             for stack in the_stacks:
                 if "/site-packages/pluggy/" not in stack:
                     if "/site-packages/_pytest/" not in stack:
                         good_stack.append(stack)
             the_traceback = "".join(good_stack)
             data_to_save.append("Traceback: " + the_traceback)
-            last_value = sys.last_value
-            if last_value:
-                data_to_save.append("Exception: " + str(last_value))
+            if hasattr(sys, "last_value"):
+                last_value = sys.last_value
+                if last_value:
+                    data_to_save.append("Exception: " + str(last_value))
         else:
             data_to_save.append("Traceback: " + the_traceback)
     log_file = codecs.open(basic_file_path, "w+", "utf-8")
@@ -140,7 +214,34 @@ def log_test_failure_data(test, test_logpath, driver, browser, url=None):
     log_file.close()
 
 
-def log_skipped_test_data(test, test_logpath, browser, reason):
+def log_skipped_test_data(test, test_logpath, driver, browser, reason):
+    browser_displayed = browser
+    driver_displayed = None
+    browser_version = None
+    driver_version = None
+    driver_name = None
+    try:
+        browser_version = get_browser_version(driver)
+    except Exception:
+        pass
+    try:
+        driver_name, driver_version = get_driver_name_and_version(
+            driver, browser
+        )
+    except Exception:
+        pass
+    if browser_version:
+        headless = ""
+        if test.headless and browser in ["chrome", "edge", "firefox"]:
+            headless = " / headless"
+        browser_displayed = "%s (%s%s)" % (browser, browser_version, headless)
+        if driver_name and driver_version:
+            driver_displayed = "%s (%s)" % (driver_name, driver_version)
+    if not browser_version:
+        browser_displayed = browser
+        driver_displayed = "(Unknown Driver)"
+    if not driver_displayed:
+        driver_displayed = "(Unknown Driver)"
     timestamp, the_date, the_time = get_master_time()
     test_id = get_test_id(test)  # pytest runnable display_id (with the "::")
     data_to_save = []
@@ -149,7 +250,8 @@ def log_skipped_test_data(test, test_logpath, browser, reason):
         "--------------------------------------------------------------------"
     )
     data_to_save.append("       Outcome: SKIPPED")
-    data_to_save.append("       Browser: %s" % browser)
+    data_to_save.append("       Browser: %s" % browser_displayed)
+    data_to_save.append("        Driver: %s" % driver_displayed)
     data_to_save.append("     Timestamp: %s" % timestamp)
     data_to_save.append("          Date: %s" % the_date)
     data_to_save.append("          Time: %s" % the_time)
@@ -191,6 +293,14 @@ def log_page_source(test_logpath, driver, source=None):
 
 
 def get_test_id(test):
+    if hasattr(test, "is_behave") and test.is_behave:
+        file_name = sb_config.behave_scenario.filename
+        line_num = sb_config.behave_line_num
+        scenario_name = sb_config.behave_scenario.name
+        if " -- @" in scenario_name:
+            scenario_name = scenario_name.split(" -- @")[0]
+        test_id = "%s:%s => %s" % (file_name, line_num, scenario_name)
+        return test_id
     test_id = None
     try:
         test_id = get_test_name(test)
@@ -289,7 +399,7 @@ def copytree(src, dst, symlinks=False, ignore=None):
 
 
 def archive_logs_if_set(log_path, archive_logs=False):
-    """ Handle Logging """
+    """Handle Logging"""
     arg_join = " ".join(sys.argv)
     if ("-n" in sys.argv) or ("-n=" in arg_join) or (arg_join == "-c"):
         return  # Skip if multithreaded
@@ -317,7 +427,7 @@ def archive_logs_if_set(log_path, archive_logs=False):
 
 
 def log_folder_setup(log_path, archive_logs=False):
-    """ Handle Logging """
+    """Handle Logging"""
     if log_path.endswith("/"):
         log_path = log_path[:-1]
     if not os.path.exists(log_path):
