@@ -89,6 +89,8 @@ def set_settings(settings_file):
             settings.HTML_REPORT = override_settings[key]
         elif key == "RESULTS_TABLE":
             settings.RESULTS_TABLE = override_settings[key]
+        elif key == "SWITCH_TO_NEW_TABS_ON_CLICK":
+            settings.SWITCH_TO_NEW_TABS_ON_CLICK = override_settings[key]
         elif key == "WAIT_FOR_RSC_ON_PAGE_LOADS":
             settings.WAIT_FOR_RSC_ON_PAGE_LOADS = override_settings[key]
         elif key == "WAIT_FOR_RSC_ON_CLICKS":
@@ -109,6 +111,14 @@ def set_settings(settings_file):
             settings.RAISE_INVALID_PROXY_STRING_EXCEPTION = override_settings[
                 key
             ]
+        elif key == "CHROME_START_WIDTH":
+            settings.CHROME_START_WIDTH = override_settings[key]
+        elif key == "CHROME_START_HEIGHT":
+            settings.CHROME_START_HEIGHT = override_settings[key]
+        elif key == "HEADLESS_START_WIDTH":
+            settings.HEADLESS_START_WIDTH = override_settings[key]
+        elif key == "HEADLESS_START_HEIGHT":
+            settings.HEADLESS_START_HEIGHT = override_settings[key]
         elif key == "MASTERQA_DEFAULT_VALIDATION_MESSAGE":
             settings.MASTERQA_DEFAULT_VALIDATION_MESSAGE = override_settings[
                 key
