@@ -4,8 +4,10 @@ These helper methods SHOULD NOT be called directly from tests.
 """
 import os
 import re
+import textwrap
 import time
 from selenium.webdriver.common.by import By
+from seleniumbase import config as sb_config
 from seleniumbase.config import settings
 from seleniumbase.core import style_sheet
 from seleniumbase.fixtures import constants
@@ -154,6 +156,16 @@ def activate_introjs(driver):
     intro_css = constants.IntroJS.MIN_CSS
     intro_js = constants.IntroJS.MIN_JS
 
+    theme_color = sb_config.introjs_theme_color
+    hover_color = sb_config.introjs_hover_color
+    backdrop_style = style_sheet.introjs_style % (
+        theme_color,
+        hover_color,
+        hover_color,
+        hover_color,
+        theme_color,
+    )
+
     verify_script = """// Verify IntroJS activated
                      var intro2 = introJs();
                      """
@@ -161,6 +173,7 @@ def activate_introjs(driver):
     activate_bootstrap(driver)
     js_utils.wait_for_ready_state_complete(driver)
     js_utils.wait_for_angularjs(driver)
+    js_utils.add_css_style(driver, backdrop_style)
     for x in range(4):
         js_utils.activate_jquery(driver)
         js_utils.add_css_link(driver, intro_css)
@@ -249,7 +262,7 @@ def is_shepherd_activated(driver):
 
 
 def play_shepherd_tour(driver, tour_steps, msg_dur, name=None, interval=0):
-    """ Plays a Shepherd tour on the current website. """
+    """Plays a Shepherd tour on the current website."""
     instructions = ""
     for tour_step in tour_steps[name]:
         instructions += tour_step
@@ -379,7 +392,7 @@ def play_shepherd_tour(driver, tour_steps, msg_dur, name=None, interval=0):
 def play_bootstrap_tour(
     driver, tour_steps, browser, msg_dur, name=None, interval=0
 ):
-    """ Plays a Bootstrap tour on the current website. """
+    """Plays a Bootstrap tour on the current website."""
     instructions = ""
     for tour_step in tour_steps[name]:
         instructions += tour_step
@@ -471,7 +484,7 @@ def play_bootstrap_tour(
 def play_driverjs_tour(
     driver, tour_steps, browser, msg_dur, name=None, interval=0
 ):
-    """ Plays a DriverJS tour on the current website. """
+    """Plays a DriverJS tour on the current website."""
     instructions = ""
     for tour_step in tour_steps[name]:
         instructions += tour_step
@@ -598,7 +611,7 @@ def play_driverjs_tour(
 def play_hopscotch_tour(
     driver, tour_steps, browser, msg_dur, name=None, interval=0
 ):
-    """ Plays a Hopscotch tour on the current website. """
+    """Plays a Hopscotch tour on the current website."""
     instructions = ""
     for tour_step in tour_steps[name]:
         instructions += tour_step
@@ -717,7 +730,7 @@ def play_hopscotch_tour(
 def play_introjs_tour(
     driver, tour_steps, browser, msg_dur, name=None, interval=0
 ):
-    """ Plays an IntroJS tour on the current website. """
+    """Plays an IntroJS tour on the current website."""
     instructions = ""
     for tour_step in tour_steps[name]:
         instructions += tour_step
@@ -727,7 +740,9 @@ def play_introjs_tour(
         intro.setOption("overlayOpacity", .29);
         intro.setOption("scrollToElement", true);
         intro.setOption("keyboardNavigation", true);
-        intro.setOption("exitOnEsc", false);
+        intro.setOption("exitOnEsc", true);
+        intro.setOption("hidePrev", true);
+        intro.setOption("nextToDone", true);
         intro.setOption("exitOnOverlayClick", false);
         intro.setOption("showStepNumbers", false);
         intro.setOption("showProgress", false);
@@ -946,7 +961,19 @@ def export_tour(tour_steps, name=None, filename="my_tour.js", url=None):
     elif tour_type == "introjs":
         intro_css = constants.IntroJS.MIN_CSS
         intro_js = constants.IntroJS.MIN_JS
+        theme_color = sb_config.introjs_theme_color
+        hover_color = sb_config.introjs_hover_color
+        backdrop_style = style_sheet.introjs_style % (
+            theme_color,
+            hover_color,
+            hover_color,
+            hover_color,
+            theme_color,
+        )
+        backdrop_style = backdrop_style.replace("\n", "")
+        backdrop_style = js_utils.escape_quotes_if_needed(backdrop_style)
         instructions += 'injectCSS("%s");\n' % intro_css
+        instructions += 'injectStyle("%s");\n' % backdrop_style
         instructions += 'injectJS("%s");' % intro_js
 
     elif tour_type == "shepherd":
@@ -982,6 +1009,8 @@ def export_tour(tour_steps, name=None, filename="my_tour.js", url=None):
         instructions += "loadResources()"
 
     instructions += "\n\n////////  Tour Code  ////////\n\n"
+    first_instructions = instructions
+    instructions = "        "
     if tour_type == "bootstrap":
         instructions += "function loadTour() { "
         instructions += 'if ( typeof Tour !== "undefined" ) {\n'
@@ -1028,7 +1057,9 @@ def export_tour(tour_steps, name=None, filename="my_tour.js", url=None):
             intro.setOption("overlayOpacity", .29);
             intro.setOption("scrollToElement", true);
             intro.setOption("keyboardNavigation", true);
-            intro.setOption("exitOnEsc", false);
+            intro.setOption("exitOnEsc", true);
+            intro.setOption("hidePrev", true);
+            intro.setOption("nextToDone", true);
             intro.setOption("exitOnOverlayClick", false);
             intro.setOption("showStepNumbers", false);
             intro.setOption("showProgress", false);
@@ -1042,6 +1073,8 @@ def export_tour(tour_steps, name=None, filename="my_tour.js", url=None):
             $tour = tour;\n"""
     else:
         pass
+    instructions = textwrap.dedent(instructions)
+    instructions = first_instructions + instructions
     instructions += '\n} else { window.setTimeout("loadTour();",100); } '
     instructions += "}\n"
     instructions += "loadTour()\n"
