@@ -8,10 +8,8 @@ import time
 from selenium.common.exceptions import NoSuchElementException
 from selenium.common.exceptions import WebDriverException
 from seleniumbase import config as sb_config
-from seleniumbase.common import decorators
 from seleniumbase.config import settings
 from seleniumbase.fixtures import constants
-from seleniumbase.fixtures import shared_utils
 
 
 def wait_for_ready_state_complete(driver, timeout=settings.LARGE_TIMEOUT):
@@ -25,12 +23,16 @@ def wait_for_ready_state_complete(driver, timeout=settings.LARGE_TIMEOUT):
       because readyState == "interactive" may be good enough.
     (Previously, tests would fail immediately if exceeding the timeout.)
     """
+    if sb_config.time_limit and not sb_config.recorder_mode:
+        from seleniumbase.fixtures import shared_utils
+
     start_ms = time.time() * 1000.0
     stop_ms = start_ms + (timeout * 1000.0)
     for x in range(int(timeout * 10)):
-        shared_utils.check_if_time_limit_exceeded()
+        if sb_config.time_limit and not sb_config.recorder_mode:
+            shared_utils.check_if_time_limit_exceeded()
         try:
-            ready_state = driver.execute_script("return document.readyState")
+            ready_state = driver.execute_script("return document.readyState;")
         except WebDriverException:
             # Bug fix for: [Permission denied to access property "document"]
             time.sleep(0.03)
@@ -78,6 +80,11 @@ def wait_for_angularjs(driver, timeout=settings.LARGE_TIMEOUT, **kwargs):
         "handler": handler,
         "suffix": suffix,
     }
+    try:
+        # This closes any pop-up alerts (otherwise the next part fails)
+        driver.execute_script("")
+    except Exception:
+        pass
     try:
         execute_async_script(driver, script, timeout=timeout)
     except Exception:
@@ -102,7 +109,7 @@ def is_jquery_activated(driver):
 
 def wait_for_jquery_active(driver, timeout=None):
     if not timeout:
-        timeout = int(settings.MINI_TIMEOUT * 10.0)
+        timeout = 22
     else:
         timeout = int(timeout * 10.0)
     for x in range(timeout):
@@ -137,15 +144,17 @@ def raise_unable_to_load_jquery_exception(driver):
         )
     else:
         raise Exception(
-            """Unable to load jQuery on "%s" because this website """
-            """restricts external JavaScript resources from loading."""
+            """Unable to load jQuery on "%s" because this website may be """
+            """restricting external JavaScript resources from loading."""
             % driver.current_url
         )
 
 
 def activate_jquery(driver):
-    """If "jQuery is not defined", use this method to activate it for use.
-    This happens because jQuery is not always defined on web sites."""
+    """
+    If "jQuery is not defined" on a website, use this method to activate it.
+    This method is needed because jQuery is not always defined on web sites.
+    """
     try:
         # Let's first find out if jQuery is already defined.
         driver.execute_script("jQuery('html');")
@@ -156,19 +165,15 @@ def activate_jquery(driver):
         pass
     jquery_js = constants.JQuery.MIN_JS
     add_js_link(driver, jquery_js)
-    for x in range(int(settings.MINI_TIMEOUT * 10.0)):
+    for x in range(27):
         # jQuery needs a small amount of time to activate.
         try:
             driver.execute_script("jQuery('html');")
             return
         except Exception:
+            if x == 15:
+                add_js_link(driver, jquery_js)
             time.sleep(0.1)
-    try:
-        add_js_link(driver, jquery_js)
-        time.sleep(0.1)
-        driver.execute_script("jQuery('head');")
-    except Exception:
-        pass
     # Since jQuery still isn't activating, give up and raise an exception
     raise_unable_to_load_jquery_exception(driver)
 
@@ -205,6 +210,31 @@ def escape_quotes_if_needed(string):
     return string
 
 
+def is_in_frame(driver):
+    """
+    Returns True if the driver has switched to a frame.
+    Returns False if the driver was on default content.
+    """
+    in_basic_frame = driver.execute_script(
+        """
+        var frame = window.frameElement;
+        if (frame) {
+            return true;
+        }
+        else {
+            return false;
+        }
+        """
+    )
+    location_href = driver.execute_script("""return window.location.href;""")
+    in_external_frame = False
+    if driver.current_url != location_href:
+        in_external_frame = True
+    if in_basic_frame or in_external_frame:
+        return True
+    return False
+
+
 def safe_execute_script(driver, script):
     """When executing a script that contains a jQuery command,
     it's important that the jQuery library has been loaded first.
@@ -228,7 +258,7 @@ def wait_for_css_query_selector(
             selector = re.escape(selector)
             selector = escape_quotes_if_needed(selector)
             element = driver.execute_script(
-                """return document.querySelector('%s')""" % selector
+                """return document.querySelector('%s');""" % selector
             )
             if element:
                 return element
@@ -245,6 +275,24 @@ def wait_for_css_query_selector(
 
 
 def highlight_with_js(driver, selector, loops, o_bs):
+    try:
+        # This closes any pop-up alerts
+        driver.execute_script("")
+    except Exception:
+        pass
+    if selector == "html":
+        selector = "body"
+    selector_no_spaces = selector.replace(" ", "")
+    early_exit = False
+    if '[style=\\"' in selector_no_spaces:
+        if "box\\-shadow:" in selector:
+            early_exit = True  # Changing the box-shadow changes the selector
+        elif '[style=\\"' in selector:
+            selector = selector.replace('[style=\\"', '[style\\*=\\"')
+        else:
+            early_exit = True  # Changing the box-shadow changes the selector
+        if early_exit:
+            return
     script = (
         """document.querySelector('%s').style.boxShadow =
         '0px 0px 6px 6px rgba(128, 128, 128, 0.5)';"""
@@ -260,52 +308,91 @@ def highlight_with_js(driver, selector, loops, o_bs):
             '0px 0px 6px 6px rgba(255, 0, 0, 1)';"""
             % selector
         )
-        driver.execute_script(script)
+        try:
+            driver.execute_script(script)
+        except Exception:
+            return
         time.sleep(0.0181)
         script = (
             """document.querySelector('%s').style.boxShadow =
             '0px 0px 6px 6px rgba(128, 0, 128, 1)';"""
             % selector
         )
-        driver.execute_script(script)
+        try:
+            driver.execute_script(script)
+        except Exception:
+            return
         time.sleep(0.0181)
         script = (
             """document.querySelector('%s').style.boxShadow =
             '0px 0px 6px 6px rgba(0, 0, 255, 1)';"""
             % selector
         )
-        driver.execute_script(script)
+        try:
+            driver.execute_script(script)
+        except Exception:
+            return
         time.sleep(0.0181)
         script = (
             """document.querySelector('%s').style.boxShadow =
             '0px 0px 6px 6px rgba(0, 255, 0, 1)';"""
             % selector
         )
-        driver.execute_script(script)
+        try:
+            driver.execute_script(script)
+        except Exception:
+            return
         time.sleep(0.0181)
         script = (
             """document.querySelector('%s').style.boxShadow =
             '0px 0px 6px 6px rgba(128, 128, 0, 1)';"""
             % selector
         )
-        driver.execute_script(script)
+        try:
+            driver.execute_script(script)
+        except Exception:
+            return
         time.sleep(0.0181)
         script = (
             """document.querySelector('%s').style.boxShadow =
             '0px 0px 6px 6px rgba(128, 0, 128, 1)';"""
             % selector
         )
-        driver.execute_script(script)
+        try:
+            driver.execute_script(script)
+        except Exception:
+            return
         time.sleep(0.0181)
     script = """document.querySelector('%s').style.boxShadow =
         '%s';""" % (
         selector,
         o_bs,
     )
-    driver.execute_script(script)
+    try:
+        driver.execute_script(script)
+    except Exception:
+        return
 
 
 def highlight_with_jquery(driver, selector, loops, o_bs):
+    try:
+        # This closes any pop-up alerts
+        driver.execute_script("")
+    except Exception:
+        pass
+    if selector == "html":
+        selector = "body"
+    selector_no_spaces = selector.replace(" ", "")
+    early_exit = False
+    if '[style=\\"' in selector_no_spaces:
+        if "box\\-shadow:" in selector:
+            early_exit = True  # Changing the box-shadow changes the selector
+        elif '[style=\\"' in selector:
+            selector = selector.replace('[style=\\"', '[style\\*=\\"')
+        else:
+            early_exit = True  # Changing the box-shadow changes the selector
+        if early_exit:
+            return
     script = (
         """jQuery('%s').css('box-shadow',
         '0px 0px 6px 6px rgba(128, 128, 128, 0.5)');"""
@@ -475,7 +562,7 @@ def activate_jquery_confirm(driver):
     add_css_link(driver, jq_confirm_css)
     add_js_link(driver, jq_confirm_js)
 
-    for x in range(int(settings.MINI_TIMEOUT * 10.0)):
+    for x in range(25):
         # jQuery-Confirm needs a small amount of time to load & activate.
         try:
             driver.execute_script("jconfirm")
@@ -501,7 +588,7 @@ def activate_html_inspector(driver):
     wait_for_ready_state_complete(driver)
     wait_for_angularjs(driver)
 
-    for x in range(int(settings.MINI_TIMEOUT * 10.0)):
+    for x in range(25):
         # HTML-Inspector needs a small amount of time to load & activate.
         try:
             driver.execute_script("HTMLInspector")
@@ -551,19 +638,19 @@ def activate_messenger(driver):
     add_js_link(driver, messenger_js)
     add_css_style(driver, style_sheet.messenger_style)
 
-    for x in range(int(settings.MINI_TIMEOUT * 10.0)):
+    for x in range(10):
         # Messenger needs a small amount of time to load & activate.
         try:
             result = driver.execute_script(
                 """ if (typeof Messenger === 'undefined') { return "U"; } """
             )
             if result == "U":
-                time.sleep(0.01)
+                time.sleep(0.02)
                 continue
             else:
                 break
         except Exception:
-            time.sleep(0.01)
+            time.sleep(0.02)
     try:
         driver.execute_script(msg_style)
         add_js_link(driver, msgr_theme_flat_js)
@@ -582,7 +669,7 @@ def set_messenger_theme(
         theme = "flat"
     if location == "default":
         location = "bottom_right"
-        if sb_config.mobile_emulator:
+        if hasattr(sb_config, "mobile_emulator") and sb_config.mobile_emulator:
             location = "top_center"
     if max_messages == "default":
         max_messages = "8"
@@ -654,7 +741,7 @@ def post_message(driver, message, msg_dur, style="info"):
             activate_messenger(driver)
             time.sleep(0.2)
             set_messenger_theme(driver)
-            time.sleep(0.5)
+            time.sleep(0.3)
             driver.execute_script(messenger_script)
 
 
@@ -665,7 +752,7 @@ def post_messenger_success_message(driver, message, msg_dur):
     try:
         theme = "flat"
         location = "bottom_right"
-        if sb_config.mobile_emulator:
+        if hasattr(sb_config, "mobile_emulator") and sb_config.mobile_emulator:
             location = "top_center"
         set_messenger_theme(driver, theme=theme, location=location)
         post_message(driver, message, msg_dur, style="success")
@@ -687,8 +774,29 @@ def post_messenger_error_message(driver, message, msg_dur):
 
 
 def highlight_with_js_2(driver, message, selector, o_bs, msg_dur):
+    try:
+        # This closes any pop-up alerts
+        driver.execute_script("")
+    except Exception:
+        pass
     if selector == "html":
         selector = "body"
+    selector_no_spaces = selector.replace(" ", "")
+    early_exit = False
+    if '[style=\\"' in selector_no_spaces:
+        if "box\\-shadow:" in selector:
+            early_exit = True  # Changing the box-shadow changes the selector
+        elif '[style=\\"' in selector:
+            selector = selector.replace('[style=\\"', '[style\\*=\\"')
+        else:
+            early_exit = True  # Changing the box-shadow changes the selector
+        if early_exit:
+            try:
+                activate_jquery(driver)
+                post_messenger_success_message(driver, message, msg_dur)
+            except Exception:
+                pass
+            return
     script = (
         """document.querySelector('%s').style.boxShadow =
         '0px 0px 6px 6px rgba(128, 128, 128, 0.5)';"""
@@ -704,28 +812,40 @@ def highlight_with_js_2(driver, message, selector, o_bs, msg_dur):
         '0px 0px 6px 6px rgba(205, 30, 0, 1)';"""
         % selector
     )
-    driver.execute_script(script)
+    try:
+        driver.execute_script(script)
+    except Exception:
+        return
     time.sleep(0.0181)
     script = (
         """document.querySelector('%s').style.boxShadow =
         '0px 0px 6px 6px rgba(128, 0, 128, 1)';"""
         % selector
     )
-    driver.execute_script(script)
+    try:
+        driver.execute_script(script)
+    except Exception:
+        return
     time.sleep(0.0181)
     script = (
         """document.querySelector('%s').style.boxShadow =
         '0px 0px 6px 6px rgba(50, 50, 128, 1)';"""
         % selector
     )
-    driver.execute_script(script)
+    try:
+        driver.execute_script(script)
+    except Exception:
+        return
     time.sleep(0.0181)
     script = (
         """document.querySelector('%s').style.boxShadow =
         '0px 0px 6px 6px rgba(50, 205, 50, 1)';"""
         % selector
     )
-    driver.execute_script(script)
+    try:
+        driver.execute_script(script)
+    except Exception:
+        return
     time.sleep(0.0181)
 
     try:
@@ -738,12 +858,31 @@ def highlight_with_js_2(driver, message, selector, o_bs, msg_dur):
         selector,
         o_bs,
     )
-    driver.execute_script(script)
+    try:
+        driver.execute_script(script)
+    except Exception:
+        return
 
 
 def highlight_with_jquery_2(driver, message, selector, o_bs, msg_dur):
     if selector == "html":
         selector = "body"
+    selector_no_spaces = selector.replace(" ", "")
+    early_exit = False
+    if '[style=\\"' in selector_no_spaces:
+        if "box\\-shadow:" in selector:
+            early_exit = True  # Changing the box-shadow changes the selector
+        elif '[style=\\"' in selector:
+            selector = selector.replace('[style=\\"', '[style\\*=\\"')
+        else:
+            early_exit = True  # Changing the box-shadow changes the selector
+        if early_exit:
+            try:
+                activate_jquery(driver)
+                post_messenger_success_message(driver, message, msg_dur)
+            except Exception:
+                pass
+            return
     script = (
         """jQuery('%s').css('box-shadow',
         '0px 0px 6px 6px rgba(128, 128, 128, 0.5)');"""
@@ -759,28 +898,40 @@ def highlight_with_jquery_2(driver, message, selector, o_bs, msg_dur):
         '0px 0px 6px 6px rgba(205, 30, 0, 1)');"""
         % selector
     )
-    driver.execute_script(script)
+    try:
+        driver.execute_script(script)
+    except Exception:
+        return
     time.sleep(0.0181)
     script = (
         """jQuery('%s').css('box-shadow',
         '0px 0px 6px 6px rgba(128, 0, 128, 1)');"""
         % selector
     )
-    driver.execute_script(script)
+    try:
+        driver.execute_script(script)
+    except Exception:
+        return
     time.sleep(0.0181)
     script = (
         """jQuery('%s').css('box-shadow',
         '0px 0px 6px 6px rgba(50, 50, 200, 1)');"""
         % selector
     )
-    driver.execute_script(script)
+    try:
+        driver.execute_script(script)
+    except Exception:
+        return
     time.sleep(0.0181)
     script = (
         """jQuery('%s').css('box-shadow',
         '0px 0px 6px 6px rgba(50, 205, 50, 1)');"""
         % selector
     )
-    driver.execute_script(script)
+    try:
+        driver.execute_script(script)
+    except Exception:
+        return
     time.sleep(0.0181)
 
     try:
@@ -790,7 +941,10 @@ def highlight_with_jquery_2(driver, message, selector, o_bs, msg_dur):
         pass
 
     script = """jQuery('%s').css('box-shadow', '%s');""" % (selector, o_bs)
-    driver.execute_script(script)
+    try:
+        driver.execute_script(script)
+    except Exception:
+        return
 
 
 def get_scroll_distance_to_element(driver, element):
@@ -864,6 +1018,8 @@ def slow_scroll_to_element(driver, element, browser):
 
 
 def get_drag_and_drop_script():
+    # This script uses jQuery to perform a Drag-and-Drop action.
+    # (Requires the Drag-selector and the Drop-selector to work)
     script = r"""(function( $ ) {
         $.fn.simulateDragDrop = function(options) {
                 return this.each(function() {
@@ -921,7 +1077,57 @@ def get_drag_and_drop_script():
     return script
 
 
+def get_js_drag_and_drop_script():
+    # HTML5 Drag-and-Drop script (Requires extra parameters to work)
+    # param1 (WebElement): Source element to drag
+    # param2 (WebElement): Target element for the drop (Optional)
+    # param3 (int): Optional - Drop offset x relative to the target
+    # param4 (int): Optional - Drop offset y relative to the target
+    # param4 (int): Optional - Delay in milliseconds (default = 1ms)
+    # param5 (string): Optional - Key pressed (ALT or CTRL or SHIFT)
+    script = """var t=arguments,e=t[0],n=t[1],i=t[2]||0,o=t[3]||0,r=t[4]||1,
+        a=t[5]||'',s='alt'===a||'\ue00a'===a,l='ctrl'===a||'\ue009'===a,
+        c='shift'===a||'\ue008'===a,u=e.ownerDocument,
+        f=e.getBoundingClientRect(),g=n?n.getBoundingClientRect():f,
+        p=f.left+f.width/2,d=f.top+f.height/2,h=g.left+(i||g.width/2),
+        m=g.top+(o||g.height/2),v=u.elementFromPoint(p,d),
+        y=u.elementFromPoint(h,m);if(!v||!y){
+        var E=new Error('source or target element is not interactable');
+        throw E.code=15,E}var _={constructor:DataTransfer,effectAllowed:null,
+        dropEffect:null,types:[],files:Object.setPrototypeOf([],null),
+        _items:Object.setPrototypeOf([],{add:function(t,e){
+        this[this.length]={_data:''+t,kind:'string',
+        type:e,getAsFile:function(){},getAsString:function(t){t(this._data)}},
+        _.types.push(e)},remove:function(t){
+        Array.prototype.splice.call(this,65535&t,1),_.types.splice(65535&t,1)},
+        clear:function(t,e){this.length=0,_.types.length=0}}),
+        setData:function(t,e){this.clearData(t),this._items.add(e,t)},
+        getData:function(t){for(var e=this._items.length;
+        e--&&this._items[e].type!==t;);return e>=0?this._items[e]._data:null},
+        clearData:function(t){for(var e=this._items.length;
+        e--&&this._items[e].type!==t;);this._items.remove(e)},
+        setDragImage:function(t){}};function w(t,e,n,i){
+        for(var o=0;o<e.length;++o){var r=u.createEvent('MouseEvent');
+        r.initMouseEvent(e[o],!0,!0,u.defaultView,0,0,0,p,d,l,s,c,!1,0,null),
+        t.dispatchEvent(r)}i&&setTimeout(i,n)}function D(t,e,n,i){
+        var o=u.createEvent('DragEvent');o.initMouseEvent(
+        e,!0,!0,u.defaultView,0,0,0,p,d,l,s,c,!1,0,null),Object.setPrototypeOf(
+        o,null),o.dataTransfer=_,Object.setPrototypeOf(o,DragEvent.prototype),
+        t.dispatchEvent(o),i&&setTimeout(i,n)}
+        'items'in DataTransfer.prototype&&(_.items=_._items),
+        w(v,['pointerdown','mousedown'],1,function(){
+        for(var t=v;t&&!t.draggable;)t=t.parentElement;if(t&&t.contains(v)){
+        var e=y.getBoundingClientRect();D(v,'dragstart',r,function(){
+        var t=y.getBoundingClientRect();p=t.left+h-e.left,d=t.top+m-e.top,D(
+        y,'dragenter',1,function(){D(y,'dragover',r,
+        function(){D(u.elementFromPoint(p,d),'drop',1,function(){D(v,'dragend',
+        1,function(){w(u.elementFromPoint(p,d),
+        ['mouseup','pointerup'])})})})})})}})"""
+    return script
+
+
 def get_drag_and_drop_with_offset_script(selector, x, y):
+    # This script uses pure JS (No jQuery)
     script_a = """
         var source = document.querySelector("%s");
         var offsetX = %f;
@@ -976,7 +1182,6 @@ def clear_out_console_logs(driver):
         pass
 
 
-@decorators.deprecated("Use re.escape() instead, which does what you want!")
 def _jq_format(code):
     """
     DEPRECATED - Use re.escape() instead, which performs the intended action.
