@@ -1,6 +1,9 @@
 """
 This module contains shared utility methods.
 """
+import fasteners
+import subprocess
+import sys
 import time
 from selenium.common.exceptions import ElementNotVisibleException
 from selenium.common.exceptions import NoAlertPresentException
@@ -8,15 +11,33 @@ from selenium.common.exceptions import NoSuchAttributeException
 from selenium.common.exceptions import NoSuchElementException
 from selenium.common.exceptions import NoSuchFrameException
 from selenium.common.exceptions import NoSuchWindowException
-from seleniumbase.common.exceptions import NoSuchFileException
-from seleniumbase.common.exceptions import TimeLimitExceededException
+from seleniumbase.common.exceptions import TextNotVisibleException
+from seleniumbase.fixtures import constants
 from seleniumbase import config as sb_config
 
 
+def pip_install(package, version=None):
+    pip_install_lock = fasteners.InterProcessLock(
+        constants.PipInstall.LOCKFILE
+    )
+    with pip_install_lock:
+        if not version:
+            subprocess.check_call(
+                [sys.executable, "-m", "pip", "install", package]
+            )
+        else:
+            package_and_version = package + "==" + str(version)
+            subprocess.check_call(
+                [sys.executable, "-m", "pip", "install", package_and_version]
+            )
+
+
 def format_exc(exception, message):
     """
     Formats an exception message to make the output cleaner.
     """
+    from seleniumbase.common.exceptions import NoSuchFileException
+
     if exception == Exception:
         exc = Exception
         return exc, message
@@ -28,6 +49,10 @@ def format_exc(exception, message):
         exc = NoSuchElementException
     elif exception == "NoSuchElementException":
         exc = NoSuchElementException
+    elif exception == TextNotVisibleException:
+        exc = TextNotVisibleException
+    elif exception == "TextNotVisibleException":
+        exc = TextNotVisibleException
     elif exception == NoAlertPresentException:
         exc = NoAlertPresentException
     elif exception == "NoAlertPresentException":
@@ -65,11 +90,17 @@ def _format_message(message):
 
 
 def __time_limit_exceeded(message):
+    from seleniumbase.common.exceptions import TimeLimitExceededException
+
     raise TimeLimitExceededException(message)
 
 
 def check_if_time_limit_exceeded():
-    if sb_config.time_limit:
+    if (
+        hasattr(sb_config, "time_limit")
+        and sb_config.time_limit
+        and not sb_config.recorder_mode
+    ):
         time_limit = sb_config.time_limit
         now_ms = int(time.time() * 1000)
         if now_ms > sb_config.start_time_ms + sb_config.time_limit_ms:
