@@ -8,6 +8,10 @@ from seleniumbase.config import settings
 from seleniumbase.core import proxy_helper
 from seleniumbase.fixtures import constants
 
+is_windows = False
+if sys.platform in ["win32", "win64", "x64"]:
+    is_windows = True
+
 
 class SeleniumBrowser(Plugin):
     """
@@ -21,42 +25,54 @@ class SeleniumBrowser(Plugin):
     --cap-string=STRING  (The web browser's desired capabilities to use.)
     --proxy=SERVER:PORT  (Connect to a proxy server:port for tests.)
     --proxy=USERNAME:PASSWORD@SERVER:PORT  (Use authenticated proxy server.)
+    --proxy-bypass-list=STRING (";"-separated hosts to bypass, Eg "*.foo.com")
+    --proxy-pac-url=URL  (Connect to a proxy server using a PAC_URL.pac file.)
+    --proxy-pac-url=USERNAME:PASSWORD@URL  (Authenticated proxy with PAC URL.)
     --agent=STRING  (Modify the web browser's User-Agent string.)
     --mobile  (Use the mobile device emulator while running tests.)
     --metrics=STRING  (Set mobile metrics: "CSSWidth,CSSHeight,PixelRatio".)
-    --chromium-arg=ARG  (Add a Chromium arg for Chrome/Edge, comma-separated.)
-    --firefox-arg=ARG  (Add a Firefox arg for Firefox, comma-separated.)
+    --chromium-arg="ARG=N,ARG2" (Set Chromium args, ","-separated, no spaces.)
+    --firefox-arg="ARG=N,ARG2" (Set Firefox args, comma-separated, no spaces.)
     --firefox-pref=SET  (Set a Firefox preference:value set, comma-separated.)
     --extension-zip=ZIP  (Load a Chrome Extension .zip|.crx, comma-separated.)
     --extension-dir=DIR  (Load a Chrome Extension directory, comma-separated.)
-    --headless  (Run tests headlessly. Default mode on Linux OS.)
-    --headed  (Run tests with a GUI on Linux OS.)
+    --headless  (Run tests in headless mode. The default arg on Linux OS.)
+    --headed  (Run tests in headed/GUI mode on Linux OS.)
+    --xvfb  (Run tests using the Xvfb virtual display server on Linux OS.)
     --locale=LOCALE_CODE  (Set the Language Locale Code for the web browser.)
     --interval=SECONDS  (The autoplay interval for presentations & tour steps)
     --start-page=URL  (The starting URL for the web browser when tests begin.)
     --time-limit=SECONDS  (Safely fail any test that exceeds the time limit.)
     --slow  (Slow down the automation. Faster than using Demo Mode.)
     --demo  (Slow down and visually see test actions as they occur.)
-    --demo-sleep=SECONDS  (Set the wait time after Demo Mode actions.)
+    --demo-sleep=SECONDS  (Set the wait time after Slow & Demo Mode actions.)
     --highlights=NUM  (Number of highlight animations for Demo Mode actions.)
     --message-duration=SECONDS  (The time length for Messenger alerts.)
     --check-js  (Check for JavaScript errors after page loads.)
-    --ad-block  (Block some types of display ads after page loads.)
-    --block-images (Block images from loading during tests.)
+    --ad-block  (Block some types of display ads from loading.)
+    --block-images  (Block images from loading during tests.)
+    --do-not-track  (Indicate to websites that you don't want to be tracked.)
     --verify-delay=SECONDS  (The delay before MasterQA verification checks.)
+    --recorder  (Enables the Recorder for turning browser actions into code.)
+    --rec-behave  (Same as Recorder Mode, but also generates behave-gherkin.)
+    --rec-sleep  (If the Recorder is enabled, also records self.sleep calls.)
+    --rec-print  (If the Recorder is enabled, prints output after tests end.)
     --disable-csp  (Disable the Content Security Policy of websites.)
     --disable-ws  (Disable Web Security on Chromium-based browsers.)
     --enable-ws  (Enable Web Security on Chromium-based browsers.)
     --enable-sync  (Enable "Chrome Sync".)
     --use-auto-ext  (Use Chrome's automation extension.)
     --remote-debug  (Enable Chrome's Remote Debugger on http://localhost:9222)
+    --final-debug  (Enter Debug Mode after each test ends. Don't use with CI!)
     --swiftshader  (Use Chrome's "--use-gl=swiftshader" feature.)
     --incognito  (Enable Chrome's Incognito mode.)
     --guest  (Enable Chrome's Guest mode.)
     --devtools  (Open Chrome's DevTools when the browser opens.)
-    --maximize  (Start tests with the web browser window maximized.)
-    --save-screenshot  (Save a screenshot at the end of each test.)
+    --window-size=WIDTH,HEIGHT  (Set the browser's starting window size.)
+    --maximize  (Start tests with the browser window maximized.)
+    --screenshot  (Save a screenshot at the end of each test.)
     --visual-baseline  (Set the visual baseline for Visual/Layout tests.)
+    --external-pdf (Set Chromium "plugins.always_open_pdf_externally": True.)
     --timeout-multiplier=MULTIPLIER  (Multiplies the default timeout values.)
     """
 
@@ -91,15 +107,16 @@ class SeleniumBrowser(Plugin):
             dest="cap_file",
             default=None,
             help="""The file that stores browser desired capabilities
-                    for BrowserStack or Sauce Labs web drivers.""",
+                    for BrowserStack, LambdaTest, Sauce Labs,
+                    and other remote web drivers to use.""",
         )
         parser.add_option(
             "--cap_string",
             "--cap-string",
             dest="cap_string",
             default=None,
-            help="""The string that stores browser desired
-                    capabilities for BrowserStack, Sauce Labs,
+            help="""The string that stores browser desired capabilities
+                    for BrowserStack, LambdaTest, Sauce Labs,
                     and other remote web drivers to use.
                     Enclose cap-string in single quotes.
                     Enclose parameter keys in double quotes.
@@ -142,10 +159,12 @@ class SeleniumBrowser(Plugin):
             dest="port",
             default="4444",
             help="""Designates the Selenium Grid port to use.
-                    Default: 4444.""",
+                    Default: 4444. (If 443, protocol becomes "https")""",
         )
         parser.add_option(
             "--proxy",
+            "--proxy-server",
+            "--proxy-string",
             action="store",
             dest="proxy_string",
             default=None,
@@ -155,6 +174,35 @@ class SeleniumBrowser(Plugin):
                             A dict key from proxy_list.PROXY_LIST
                     Default: None.""",
         )
+        parser.add_option(
+            "--proxy-bypass-list",
+            "--proxy_bypass_list",
+            action="store",
+            dest="proxy_bypass_list",
+            default=None,
+            help="""Designates the hosts, domains, and/or IP addresses
+                    to bypass when using a proxy server with "--proxy".
+                    Format: A ";"-separated string.
+                    Example usage:
+                        pytest
+                            --proxy="username:password@servername:port"
+                            --proxy-bypass-list="*.foo.com;github.com"
+                        pytest
+                            --proxy="servername:port"
+                            --proxy-bypass-list="127.0.0.1:8080"
+                    Default: None.""",
+        )
+        parser.add_option(
+            "--proxy-pac-url",
+            "--pac-url",
+            action="store",
+            dest="proxy_pac_url",
+            default=None,
+            help="""Designates the proxy PAC URL to use.
+                    Format: A URL string  OR
+                            A username:password@URL string
+                    Default: None.""",
+        )
         parser.add_option(
             "--agent",
             "--user-agent",
@@ -273,6 +321,17 @@ class SeleniumBrowser(Plugin):
                     (The default setting on Linux is headless.)
                     (The default setting on Mac or Windows is headed.)""",
         )
+        parser.add_option(
+            "--xvfb",
+            action="store_true",
+            dest="xvfb",
+            default=False,
+            help="""Using this makes tests run headlessly using Xvfb
+                    instead of the browser's built-in headless mode.
+                    When using "--xvfb", the "--headless" option
+                    will no longer be enabled by default on Linux.
+                    Default: False. (Linux-ONLY!)""",
+        )
         parser.add_option(
             "--locale_code",
             "--locale-code",
@@ -321,6 +380,7 @@ class SeleniumBrowser(Plugin):
         parser.add_option(
             "--slow_mode",
             "--slow-mode",
+            "--slowmo",
             "--slow",
             action="store_true",
             dest="slow_mode",
@@ -374,6 +434,7 @@ class SeleniumBrowser(Plugin):
                     every page load.""",
         )
         parser.add_option(
+            "--adblock",
             "--ad_block",
             "--ad-block",
             "--block_ads",
@@ -393,6 +454,17 @@ class SeleniumBrowser(Plugin):
             help="""Using this makes WebDriver block images from
                     loading on web pages during tests.""",
         )
+        parser.add_option(
+            "--do_not_track",
+            "--do-not-track",
+            action="store_true",
+            dest="do_not_track",
+            default=False,
+            help="""Indicate to websites that you don't want to be
+                    tracked. The browser will send an extra HTTP
+                    header each time it requests a web page.
+                    https://support.google.com/chrome/answer/2790761""",
+        )
         parser.add_option(
             "--verify_delay",
             "--verify-delay",
@@ -402,9 +474,53 @@ class SeleniumBrowser(Plugin):
             help="""Setting this overrides the default wait time
                     before each MasterQA verification pop-up.""",
         )
+        parser.add_option(
+            "--recorder",
+            "--record",
+            "--rec",
+            "--codegen",
+            action="store_true",
+            dest="recorder_mode",
+            default=False,
+            help="""Using this enables the SeleniumBase Recorder,
+                    which records browser actions for converting
+                    into SeleniumBase scripts.""",
+        )
+        parser.add_option(
+            "--rec-behave",
+            "--rec-gherkin",
+            action="store_true",
+            dest="rec_behave",
+            default=False,
+            help="""Not only enables the SeleniumBase Recorder,
+                    but also saves recorded actions into the
+                    behave-gerkin format, which includes a
+                    feature file, an imported steps file,
+                    and the environment.py file.""",
+        )
+        parser.add_option(
+            "--rec-sleep",
+            "--record-sleep",
+            action="store_true",
+            dest="record_sleep",
+            default=False,
+            help="""If Recorder Mode is enabled,
+                    records sleep(seconds) calls.""",
+        )
+        parser.add_option(
+            "--rec-print",
+            action="store_true",
+            dest="rec_print",
+            default=False,
+            help="""If Recorder Mode is enabled,
+                    prints output after tests end.""",
+        )
         parser.add_option(
             "--disable_csp",
             "--disable-csp",
+            "--no_csp",
+            "--no-csp",
+            "--dcsp",
             action="store_true",
             dest="disable_csp",
             default=False,
@@ -483,6 +599,16 @@ class SeleniumBrowser(Plugin):
                     http://localhost:9222 while Chromedriver is running.
                     Info: chromedevtools.github.io/devtools-protocol/""",
         )
+        parser.add_option(
+            "--final-debug",
+            action="store_true",
+            dest="final_debug",
+            default=False,
+            help="""Enter Debug Mode at the end of each test.
+                    To enter Debug Mode only on failures, use "--pdb".
+                    If using both "--final-debug" and "--pdb" together,
+                    then Debug Mode will activate twice on failures.""",
+        )
         parser.add_option(
             "--swiftshader",
             action="store_true",
@@ -518,6 +644,17 @@ class SeleniumBrowser(Plugin):
             default=False,
             help="""Using this opens Chrome's DevTools.""",
         )
+        parser.add_option(
+            "--window-size",
+            "--window_size",
+            action="store",
+            dest="window_size",
+            default=None,
+            help="""The option to set the default window "width,height".
+                    Format: A comma-separated string with the 2 values.
+                    Example: "1200,800"
+                    Default: None. (Will use default values if None)""",
+        )
         parser.add_option(
             "--maximize_window",
             "--maximize-window",
@@ -526,16 +663,18 @@ class SeleniumBrowser(Plugin):
             action="store_true",
             dest="maximize_option",
             default=False,
-            help="""The option to start with the web browser maximized.""",
+            help="""The option to start with a maximized browser window.
+                    (Overrides the "window-size" option if used.)""",
         )
         parser.add_option(
+            "--screenshot",
             "--save_screenshot",
             "--save-screenshot",
+            "--ss",
             action="store_true",
             dest="save_screenshot",
             default=False,
-            help="""(DEPRECATED) - Screenshots are enabled by default now.
-                    This option saves screenshots during test failures.
+            help="""Save a screenshot at the end of the test.
                     (Added to the "latest_logs/" folder.)""",
         )
         parser.add_option(
@@ -549,6 +688,17 @@ class SeleniumBrowser(Plugin):
                     When a test calls self.check_window(), it will
                     rebuild its files in the visual_baseline folder.""",
         )
+        parser.add_option(
+            "--external_pdf",
+            "--external-pdf",
+            action="store_true",
+            dest="external_pdf",
+            default=False,
+            help="""This option sets the following on Chromium:
+                    "plugins.always_open_pdf_externally": True,
+                    which causes opened PDF URLs to download immediately,
+                    instead of being displayed in the browser window.""",
+        )
         parser.add_option(
             "--timeout_multiplier",
             "--timeout-multiplier",
@@ -568,11 +718,44 @@ class SeleniumBrowser(Plugin):
         proxy_helper.remove_proxy_zip_if_present()
 
     def beforeTest(self, test):
+        browser = self.options.browser
+        if self.options.recorder_mode and browser not in ["chrome", "edge"]:
+            message = (
+                "\n\n  Recorder Mode ONLY supports Chrome and Edge!"
+                '\n  (Your browser choice was: "%s")\n' % browser
+            )
+            raise Exception(message)
+        window_size = self.options.window_size
+        if window_size:
+            if window_size.count(",") != 1:
+                message = (
+                    '\n\n  window_size expects a "width,height" string!'
+                    '\n  (Your input was: "%s")\n' % window_size
+                )
+                raise Exception(message)
+            window_size = window_size.replace(" ", "")
+            width = None
+            height = None
+            try:
+                width = int(window_size.split(",")[0])
+                height = int(window_size.split(",")[1])
+            except Exception:
+                message = (
+                    '\n\n  Expecting integer values for "width,height"!'
+                    '\n  (window_size input was: "%s")\n' % window_size
+                )
+                raise Exception(message)
+            settings.CHROME_START_WIDTH = width
+            settings.CHROME_START_HEIGHT = height
+            settings.HEADLESS_START_WIDTH = width
+            settings.HEADLESS_START_HEIGHT = height
+        test.test.is_nosetest = True
         test.test.browser = self.options.browser
         test.test.cap_file = self.options.cap_file
         test.test.cap_string = self.options.cap_string
         test.test.headless = self.options.headless
         test.test.headed = self.options.headed
+        test.test.xvfb = self.options.xvfb
         test.test.locale_code = self.options.locale_code
         test.test.interval = self.options.interval
         test.test.start_page = self.options.start_page
@@ -586,6 +769,8 @@ class SeleniumBrowser(Plugin):
         test.test.firefox_arg = self.options.firefox_arg
         test.test.firefox_pref = self.options.firefox_pref
         test.test.proxy_string = self.options.proxy_string
+        test.test.proxy_bypass_list = self.options.proxy_bypass_list
+        test.test.proxy_pac_url = self.options.proxy_pac_url
         test.test.user_agent = self.options.user_agent
         test.test.mobile_emulator = self.options.mobile_emulator
         test.test.device_metrics = self.options.device_metrics
@@ -598,7 +783,22 @@ class SeleniumBrowser(Plugin):
         test.test.js_checking_on = self.options.js_checking_on
         test.test.ad_block_on = self.options.ad_block_on
         test.test.block_images = self.options.block_images
+        test.test.do_not_track = self.options.do_not_track
         test.test.verify_delay = self.options.verify_delay  # MasterQA
+        test.test.recorder_mode = self.options.recorder_mode
+        test.test.recorder_ext = self.options.recorder_mode  # Again
+        test.test.rec_behave = self.options.rec_behave
+        test.test.rec_print = self.options.rec_print
+        test.test.record_sleep = self.options.record_sleep
+        if self.options.rec_print:
+            test.test.recorder_mode = True
+            test.test.recorder_ext = True
+        elif self.options.rec_behave:
+            test.test.recorder_mode = True
+            test.test.recorder_ext = True
+        elif self.options.record_sleep:
+            test.test.recorder_mode = True
+            test.test.recorder_ext = True
         test.test.disable_csp = self.options.disable_csp
         test.test.disable_ws = self.options.disable_ws
         test.test.enable_ws = self.options.enable_ws
@@ -609,27 +809,39 @@ class SeleniumBrowser(Plugin):
         test.test.no_sandbox = self.options.no_sandbox
         test.test.disable_gpu = self.options.disable_gpu
         test.test.remote_debug = self.options.remote_debug
+        test.test._final_debug = self.options.final_debug
         test.test.swiftshader = self.options.swiftshader
         test.test.incognito = self.options.incognito
         test.test.guest_mode = self.options.guest_mode
         test.test.devtools = self.options.devtools
+        test.test.window_size = self.options.window_size
         test.test.maximize_option = self.options.maximize_option
         test.test.save_screenshot_after_test = self.options.save_screenshot
         test.test.visual_baseline = self.options.visual_baseline
+        test.test.external_pdf = self.options.external_pdf
         test.test.timeout_multiplier = self.options.timeout_multiplier
-        test.test.use_grid = False
         test.test.dashboard = False
         test.test._multithreaded = False
         test.test._reuse_session = False
         if test.test.servername != "localhost":
-            # Use Selenium Grid (Use --server="127.0.0.1" for localhost Grid)
-            test.test.use_grid = True
-        if "linux" in sys.platform and (
-            not self.options.headed and not self.options.headless
+            # Using Selenium Grid
+            # (Set --server="127.0.0.1" for localhost Grid)
+            if str(self.options.port) == "443":
+                test.test.protocol = "https"
+        if self.options.xvfb and "linux" not in sys.platform:
+            # The Xvfb virtual display server is for Linux OS Only!
+            self.options.xvfb = False
+        if (
+            "linux" in sys.platform
+            and not self.options.headed
+            and not self.options.headless
+            and not self.options.xvfb
         ):
             print(
-                "(Running with --headless on Linux. "
-                "Use --headed or --gui to override.)"
+                "(Linux uses --headless by default. "
+                "To override, use --headed / --gui. "
+                "For Xvfb mode instead, use --xvfb. "
+                "Or hide this info with --headless.)"
             )
             self.options.headless = True
             test.test.headless = True
@@ -656,18 +868,23 @@ class SeleniumBrowser(Plugin):
         test.test.driver = self.driver
 
     def finalize(self, result):
-        """ This runs after all tests have completed with nosetests. """
+        """This runs after all tests have completed with nosetests."""
         proxy_helper.remove_proxy_zip_if_present()
 
     def afterTest(self, test):
         try:
             # If the browser window is still open, close it now.
-            self.driver.quit()
+            if (
+                not is_windows
+                or test.test.browser == "ie"
+                or self.driver.service.process
+            ):
+                self.driver.quit()
         except AttributeError:
             pass
         except Exception:
             pass
-        if self.options.headless:
+        if self.options.headless or self.options.xvfb:
             if self.headless_active:
                 try:
                     self.display.stop()
