@@ -236,6 +236,14 @@ class Testgeval(BaseCase):
         # activate_jquery()
         return self.activate_jquery(*args, **kwargs)
 
+    def activeer_recorder(self, *args, **kwargs):
+        # activate_recorder()
+        return self.activate_recorder(*args, **kwargs)
+
+    def openen_zo_niet_url(self, *args, **kwargs):
+        # open_if_not_url(url)
+        return self.open_if_not_url(*args, **kwargs)
+
     def blokkeer_advertenties(self, *args, **kwargs):
         # ad_block()
         return self.ad_block(*args, **kwargs)
@@ -260,6 +268,10 @@ class Testgeval(BaseCase):
         # switch_to_default_content()
         return self.switch_to_default_content(*args, **kwargs)
 
+    def overschakelen_naar_bovenliggend_frame(self, *args, **kwargs):
+        # switch_to_parent_frame()
+        return self.switch_to_parent_frame(*args, **kwargs)
+
     def nieuw_venster_openen(self, *args, **kwargs):
         # open_new_window()
         return self.open_new_window(*args, **kwargs)
