@@ -236,6 +236,14 @@ class CasoDiProva(BaseCase):
         # activate_jquery()
         return self.activate_jquery(*args, **kwargs)
 
+    def attiva_recorder(self, *args, **kwargs):
+        # activate_recorder()
+        return self.activate_recorder(*args, **kwargs)
+
+    def apri_se_non_url(self, *args, **kwargs):
+        # open_if_not_url(url)
+        return self.open_if_not_url(*args, **kwargs)
+
     def bloccare_gli_annunci(self, *args, **kwargs):
         # ad_block()
         return self.ad_block(*args, **kwargs)
@@ -252,7 +260,7 @@ class CasoDiProva(BaseCase):
         # assert_no_js_errors()
         return self.assert_no_js_errors(*args, **kwargs)
 
-    def passa_al_frame(self, *args, **kwargs):
+    def passa_alla_cornice(self, *args, **kwargs):
         # switch_to_frame(frame)
         return self.switch_to_frame(*args, **kwargs)
 
@@ -260,6 +268,10 @@ class CasoDiProva(BaseCase):
         # switch_to_default_content()
         return self.switch_to_default_content(*args, **kwargs)
 
+    def passa_alla_cornice_principale(self, *args, **kwargs):
+        # switch_to_parent_frame()
+        return self.switch_to_parent_frame(*args, **kwargs)
+
     def apri_una_nuova_finestra(self, *args, **kwargs):
         # open_new_window()
         return self.open_new_window(*args, **kwargs)
