@@ -236,6 +236,14 @@ class セレニウムテストケース(BaseCase):  # noqa
         # activate_jquery()
         return self.activate_jquery(*args, **kwargs)
 
+    def RECORDERを読み込む(self, *args, **kwargs):
+        # activate_recorder()
+        return self.activate_recorder(*args, **kwargs)
+
+    def URLでない場合は開く(self, *args, **kwargs):
+        # open_if_not_url(url)
+        return self.open_if_not_url(*args, **kwargs)
+
     def ブロック広告(self, *args, **kwargs):
         # ad_block()
         return self.ad_block(*args, **kwargs)
@@ -252,7 +260,7 @@ class セレニウムテストケース(BaseCase):  # noqa
         # assert_no_js_errors()
         return self.assert_no_js_errors(*args, **kwargs)
 
-    def フレームに切り替え(self, *args, **kwargs):
+    def フレームに切り替えます(self, *args, **kwargs):
         # switch_to_frame(frame)
         return self.switch_to_frame(*args, **kwargs)
 
@@ -260,6 +268,10 @@ class セレニウムテストケース(BaseCase):  # noqa
         # switch_to_default_content()
         return self.switch_to_default_content(*args, **kwargs)
 
+    def 親フレームに切り替えます(self, *args, **kwargs):
+        # switch_to_parent_frame()
+        return self.switch_to_parent_frame(*args, **kwargs)
+
     def 新しいウィンドウを開く(self, *args, **kwargs):
         # open_new_window()
         return self.open_new_window(*args, **kwargs)
