@@ -236,6 +236,14 @@ class CasoDeTeste(BaseCase):
         # activate_jquery()
         return self.activate_jquery(*args, **kwargs)
 
+    def ativar_recorder(self, *args, **kwargs):
+        # activate_recorder()
+        return self.activate_recorder(*args, **kwargs)
+
+    def abrir_se_não_url(self, *args, **kwargs):
+        # open_if_not_url(url)
+        return self.open_if_not_url(*args, **kwargs)
+
     def bloquear_anúncios(self, *args, **kwargs):
         # ad_block()
         return self.ad_block(*args, **kwargs)
@@ -260,6 +268,10 @@ class CasoDeTeste(BaseCase):
         # switch_to_default_content()
         return self.switch_to_default_content(*args, **kwargs)
 
+    def mudar_para_o_quadro_pai(self, *args, **kwargs):
+        # switch_to_parent_frame()
+        return self.switch_to_parent_frame(*args, **kwargs)
+
     def abrir_nova_janela(self, *args, **kwargs):
         # open_new_window()
         return self.open_new_window(*args, **kwargs)
